@@ -30,14 +30,14 @@ import static org.apache.iceberg.expressions.Expressions.notStartsWith;
 import static org.apache.iceberg.expressions.Expressions.or;
 import static org.apache.iceberg.expressions.Expressions.startsWith;
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import org.apache.iceberg.TestHelpers;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.StructType;
 import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TestExpressionBinding {
   private static final StructType STRUCT =
@@ -100,9 +100,9 @@ public class TestExpressionBinding {
 
     // make sure the refs are for the right fields
     BoundPredicate<?> left = TestHelpers.assertAndUnwrap(and.left());
-    Assert.assertEquals("Should bind x correctly", 0, left.term().ref().fieldId());
+    assertThat(left.term().ref().fieldId()).as("Should bind x correctly").isZero();
     BoundPredicate<?> right = TestHelpers.assertAndUnwrap(and.right());
-    Assert.assertEquals("Should bind y correctly", 1, right.term().ref().fieldId());
+    assertThat(right.term().ref().fieldId()).as("Should bind y correctly").isOne();
   }
 
   @Test
@@ -116,9 +116,9 @@ public class TestExpressionBinding {
 
     // make sure the refs are for the right fields
     BoundPredicate<?> left = TestHelpers.assertAndUnwrap(or.left());
-    Assert.assertEquals("Should bind z correctly", 2, left.term().ref().fieldId());
+    assertThat(left.term().ref().fieldId()).as("Should bind z correctly").isEqualTo(2);
     BoundPredicate<?> right = TestHelpers.assertAndUnwrap(or.right());
-    Assert.assertEquals("Should bind y correctly", 1, right.term().ref().fieldId());
+    assertThat(right.term().ref().fieldId()).as("Should bind y correctly").isOne();
   }
 
   @Test
@@ -132,7 +132,7 @@ public class TestExpressionBinding {
 
     // make sure the refs are for the right fields
     BoundPredicate<?> child = TestHelpers.assertAndUnwrap(not.child());
-    Assert.assertEquals("Should bind x correctly", 0, child.term().ref().fieldId());
+    assertThat(child.term().ref().fieldId()).as("Should bind x correctly").isZero();
   }
 
   @Test
@@ -143,8 +143,10 @@ public class TestExpressionBinding {
     TestHelpers.assertAllReferencesBound("StartsWith", boundExpr);
     // make sure the expression is a StartsWith
     BoundPredicate<?> pred = TestHelpers.assertAndUnwrap(boundExpr, BoundPredicate.class);
-    Assert.assertEquals("Should be right operation", Expression.Operation.STARTS_WITH, pred.op());
-    Assert.assertEquals("Should bind s correctly", 0, pred.term().ref().fieldId());
+    assertThat(pred.op())
+        .as("Should be right operation")
+        .isEqualTo(Expression.Operation.STARTS_WITH);
+    assertThat(pred.term().ref().fieldId()).as("Should bind s correctly").isZero();
   }
 
   @Test
@@ -155,21 +157,26 @@ public class TestExpressionBinding {
     TestHelpers.assertAllReferencesBound("NotStartsWith", boundExpr);
     // Make sure the expression is a NotStartsWith
     BoundPredicate<?> pred = TestHelpers.assertAndUnwrap(boundExpr, BoundPredicate.class);
-    Assert.assertEquals(
-        "Should be right operation", Expression.Operation.NOT_STARTS_WITH, pred.op());
-    Assert.assertEquals("Should bind term to correct field id", 21, pred.term().ref().fieldId());
+    assertThat(pred.op())
+        .as("Should be right operation")
+        .isEqualTo(Expression.Operation.NOT_STARTS_WITH);
+    assertThat(pred.term().ref().fieldId())
+        .as("Should bind term to correct field id")
+        .isEqualTo(21);
   }
 
   @Test
   public void testAlwaysTrue() {
-    Assert.assertEquals(
-        "Should not change alwaysTrue", alwaysTrue(), Binder.bind(STRUCT, alwaysTrue()));
+    assertThat(Binder.bind(STRUCT, alwaysTrue()))
+        .as("Should not change alwaysTrue")
+        .isEqualTo(alwaysTrue());
   }
 
   @Test
   public void testAlwaysFalse() {
-    Assert.assertEquals(
-        "Should not change alwaysFalse", alwaysFalse(), Binder.bind(STRUCT, alwaysFalse()));
+    assertThat(Binder.bind(STRUCT, alwaysFalse()))
+        .as("Should not change alwaysFalse")
+        .isEqualTo(alwaysFalse());
   }
 
   @Test
@@ -179,19 +186,17 @@ public class TestExpressionBinding {
 
     // the second predicate is always true once it is bound because z is an integer and the literal
     // is less than any 32-bit integer value
-    Assert.assertEquals(
-        "Should simplify or expression to alwaysTrue",
-        alwaysTrue(),
-        Binder.bind(STRUCT, or(lessThan("y", 100), greaterThan("z", -9999999999L))));
+    assertThat(Binder.bind(STRUCT, or(lessThan("y", 100), greaterThan("z", -9999999999L))))
+        .as("Should simplify or expression to alwaysTrue")
+        .isEqualTo(alwaysTrue());
     // similarly, the second predicate is always false
-    Assert.assertEquals(
-        "Should simplify and expression to predicate",
-        alwaysFalse(),
-        Binder.bind(STRUCT, and(lessThan("y", 100), lessThan("z", -9999999999L))));
+    assertThat(Binder.bind(STRUCT, and(lessThan("y", 100), lessThan("z", -9999999999L))))
+        .as("Should simplify and expression to predicate")
+        .isEqualTo(alwaysFalse());
 
     Expression bound = Binder.bind(STRUCT, not(not(lessThan("y", 100))));
     BoundPredicate<?> pred = TestHelpers.assertAndUnwrap(bound);
-    Assert.assertEquals("Should have the correct bound field", 1, pred.term().ref().fieldId());
+    assertThat(pred.term().ref().fieldId()).as("Should have the correct bound field").isOne();
   }
 
   @Test
@@ -203,7 +208,8 @@ public class TestExpressionBinding {
         .as("Should use a BoundTransform child")
         .isInstanceOf(BoundTransform.class);
     BoundTransform<?, ?> transformExpr = (BoundTransform<?, ?>) pred.term();
-    Assert.assertEquals(
-        "Should use a bucket[16] transform", "bucket[16]", transformExpr.transform().toString());
+    assertThat(transformExpr.transform())
+        .as("Should use a bucket[16] transform")
+        .hasToString("bucket[16]");
   }
 }
