@@ -19,8 +19,10 @@
 package org.apache.iceberg.util;
 
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.Set;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
 import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -79,4 +81,35 @@ public class TestCharSequenceSet {
 
     Assertions.assertThat(set).isEmpty();
   }
+
+  @Test
+  public void testEqualsAndHashCode() {
+    CharSequenceSet set1 = CharSequenceSet.empty();
+    CharSequenceSet set2 = CharSequenceSet.empty();
+
+    Assertions.assertThat(set1).isEqualTo(set2);
+    Assertions.assertThat(set1.hashCode()).isEqualTo(set2.hashCode());
+
+    set1.add("v1");
+    set1.add("v2");
+    set1.add("v3");
+
+    set2.add(new StringBuilder("v1"));
+    set2.add(new StringBuffer("v2"));
+    set2.add("v3");
+
+    Set<CharSequence> set3 = Collections.unmodifiableSet(set2);
+
+    Set<CharSequenceWrapper> set4 =
+        ImmutableSet.of(
+            CharSequenceWrapper.wrap("v1"),
+            CharSequenceWrapper.wrap(new StringBuffer("v2")),
+            CharSequenceWrapper.wrap(new StringBuffer("v3")));
+
+    Assertions.assertThat(set1).isEqualTo(set2).isEqualTo(set3).isEqualTo(set4);
+    Assertions.assertThat(set1.hashCode())
+        .isEqualTo(set2.hashCode())
+        .isEqualTo(set3.hashCode())
+        .isEqualTo(set4.hashCode());
+  }
 }
