@@ -21,7 +21,9 @@ package org.apache.iceberg.view;
 import java.io.Serializable;
 import java.util.Comparator;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.UUID;
 import java.util.stream.Collectors;
@@ -30,19 +32,20 @@ import javax.annotation.Nullable;
 import org.apache.iceberg.MetadataUpdate;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.exceptions.ValidationException;
+import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.util.PropertyUtil;
 import org.immutables.value.Value;
-import org.immutables.value.Value.Style.ImplementationVisibility;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @SuppressWarnings("ImmutablesStyle")
 @Value.Immutable(builder = false)
-@Value.Style(allParameters = true, visibility = ImplementationVisibility.PACKAGE)
+@Value.Style(allParameters = true, visibilityString = "PACKAGE")
 public interface ViewMetadata extends Serializable {
   Logger LOG = LoggerFactory.getLogger(ViewMetadata.class);
   int SUPPORTED_VIEW_FORMAT_VERSION = 1;
@@ -139,6 +142,7 @@ public interface ViewMetadata extends Serializable {
   }
 
   class Builder {
+    private static final int INITIAL_SCHEMA_ID = 0;
     private static final int LAST_ADDED = -1;
     private final List<ViewVersion> versions;
     private final List<Schema> schemas;
@@ -153,6 +157,9 @@ public interface ViewMetadata extends Serializable {
 
     // internal change tracking
     private Integer lastAddedVersionId = null;
+    private Integer lastAddedSchemaId = null;
+    private ViewHistoryEntry historyEntry = null;
+    private ViewVersion previousViewVersion = null;
 
     // indexes
     private final Map<Integer, ViewVersion> versionsById;
@@ -182,6 +189,7 @@ public interface ViewMetadata extends Serializable {
       this.location = base.location();
       this.uuid = base.uuid();
       this.metadataLocation = null;
+      this.previousViewVersion = base.currentVersion();
     }
 
     public Builder upgradeFormatVersion(int newFormatVersion) {
@@ -240,6 +248,12 @@ public interface ViewMetadata extends Serializable {
         changes.add(new MetadataUpdate.SetCurrentViewVersion(newVersionId));
       }
 
+      this.historyEntry =
+          ImmutableViewHistoryEntry.builder()
+              .timestampMillis(version.timestampMillis())
+              .versionId(version.versionId())
+              .build();
+
       return this;
     }
 
@@ -255,8 +269,13 @@ public interface ViewMetadata extends Serializable {
       return this;
     }
 
-    private int addVersionInternal(ViewVersion version) {
-      int newVersionId = reuseOrCreateNewViewVersionId(version);
+    private int addVersionInternal(ViewVersion newVersion) {
+      int newVersionId = reuseOrCreateNewViewVersionId(newVersion);
+      ViewVersion version = newVersion;
+      if (newVersionId != version.versionId()) {
+        version = ImmutableViewVersion.builder().from(version).versionId(newVersionId).build();
+      }
+
       if (versionsById.containsKey(newVersionId)) {
         boolean addedInBuilder =
             changes(MetadataUpdate.AddViewVersion.class)
@@ -265,26 +284,39 @@ public interface ViewMetadata extends Serializable {
         return newVersionId;
       }
 
+      if (newVersion.schemaId() == LAST_ADDED) {
+        ValidationException.check(
+            lastAddedSchemaId != null, "Cannot set last added schema: no schema has been added");
+        version =
+            ImmutableViewVersion.builder().from(newVersion).schemaId(lastAddedSchemaId).build();
+      }
+
       Preconditions.checkArgument(
           schemasById.containsKey(version.schemaId()),
           "Cannot add version with unknown schema: %s",
           version.schemaId());
 
-      ViewVersion newVersion;
-      if (newVersionId != version.versionId()) {
-        newVersion = ImmutableViewVersion.builder().from(version).versionId(newVersionId).build();
-      } else {
-        newVersion = version;
+      Set<String> dialects = Sets.newHashSet();
+      for (ViewRepresentation repr : version.representations()) {
+        if (repr instanceof SQLViewRepresentation) {
+          SQLViewRepresentation sql = (SQLViewRepresentation) repr;
+          Preconditions.checkArgument(
+              dialects.add(sql.dialect().toLowerCase(Locale.ROOT)),
+              "Invalid view version: Cannot add multiple queries for dialect %s",
+              sql.dialect().toLowerCase(Locale.ROOT));
+        }
       }
 
-      versions.add(newVersion);
-      versionsById.put(newVersion.versionId(), newVersion);
-      changes.add(new MetadataUpdate.AddViewVersion(newVersion));
-      history.add(
-          ImmutableViewHistoryEntry.builder()
-              .timestampMillis(newVersion.timestampMillis())
-              .versionId(newVersion.versionId())
-              .build());
+      versions.add(version);
+      versionsById.put(version.versionId(), version);
+
+      if (null != lastAddedSchemaId && version.schemaId() == lastAddedSchemaId) {
+        changes.add(
+            new MetadataUpdate.AddViewVersion(
+                ImmutableViewVersion.builder().from(version).schemaId(LAST_ADDED).build()));
+      } else {
+        changes.add(new MetadataUpdate.AddViewVersion(version));
+      }
 
       this.lastAddedVersionId = newVersionId;
 
@@ -295,16 +327,32 @@ public interface ViewMetadata extends Serializable {
       // if the view version already exists, use its id; otherwise use the highest id + 1
       int newVersionId = viewVersion.versionId();
       for (ViewVersion version : versions) {
-        if (version.equals(viewVersion)) {
+        if (sameViewVersion(version, viewVersion)) {
           return version.versionId();
         } else if (version.versionId() >= newVersionId) {
-          newVersionId = viewVersion.versionId() + 1;
+          newVersionId = version.versionId() + 1;
         }
       }
 
       return newVersionId;
     }
 
+    /**
+     * Checks whether the given view versions would behave the same while ignoring the view version
+     * id, the creation timestamp, and the operation.
+     *
+     * @param one the view version to compare
+     * @param two the view version to compare
+     * @return true if the given view versions would behave the same
+     */
+    private boolean sameViewVersion(ViewVersion one, ViewVersion two) {
+      return Objects.equals(one.summary(), two.summary())
+          && Objects.equals(one.representations(), two.representations())
+          && Objects.equals(one.defaultCatalog(), two.defaultCatalog())
+          && Objects.equals(one.defaultNamespace(), two.defaultNamespace())
+          && one.schemaId() == two.schemaId();
+    }
+
     public Builder addSchema(Schema schema) {
       addSchemaInternal(schema);
       return this;
@@ -329,6 +377,8 @@ public interface ViewMetadata extends Serializable {
       schemasById.put(newSchema.schemaId(), newSchema);
       changes.add(new MetadataUpdate.AddSchema(newSchema, highestFieldId));
 
+      this.lastAddedSchemaId = newSchemaId;
+
       return newSchemaId;
     }
 
@@ -338,7 +388,7 @@ public interface ViewMetadata extends Serializable {
 
     private int reuseOrCreateNewSchemaId(Schema newSchema) {
       // if the schema already exists, use its id; otherwise use the highest id + 1
-      int newSchemaId = newSchema.schemaId();
+      int newSchemaId = INITIAL_SCHEMA_ID;
       for (Schema schema : schemas) {
         if (schema.sameSchema(newSchema)) {
           return schema.schemaId();
@@ -384,7 +434,7 @@ public interface ViewMetadata extends Serializable {
 
     public ViewMetadata build() {
       Preconditions.checkArgument(null != location, "Invalid location: null");
-      Preconditions.checkArgument(versions.size() > 0, "Invalid view: no versions were added");
+      Preconditions.checkArgument(!versions.isEmpty(), "Invalid view: no versions were added");
 
       // when associated with a metadata file, metadata must have no changes so that the metadata
       // matches exactly what is in the metadata file, which does not store changes. metadata
@@ -393,6 +443,18 @@ public interface ViewMetadata extends Serializable {
           metadataLocation == null || changes.isEmpty(),
           "Cannot create view metadata with a metadata location and changes");
 
+      if (null != historyEntry) {
+        history.add(historyEntry);
+      }
+
+      if (null != previousViewVersion
+          && !PropertyUtil.propertyAsBoolean(
+              properties,
+              ViewProperties.REPLACE_DROP_DIALECT_ALLOWED,
+              ViewProperties.REPLACE_DROP_DIALECT_ALLOWED_DEFAULT)) {
+        checkIfDialectIsDropped(previousViewVersion, versionsById.get(currentVersionId));
+      }
+
       int historySize =
           PropertyUtil.propertyAsInt(
               properties,
@@ -434,6 +496,7 @@ public interface ViewMetadata extends Serializable {
           metadataLocation);
     }
 
+    @VisibleForTesting
     static List<ViewVersion> expireVersions(
         Map<Integer, ViewVersion> versionsById, int numVersionsToKeep) {
       // version ids are assigned sequentially. keep the latest versions by ID.
@@ -448,6 +511,7 @@ public interface ViewMetadata extends Serializable {
       return retainedVersions;
     }
 
+    @VisibleForTesting
     static List<ViewHistoryEntry> updateHistory(List<ViewHistoryEntry> history, Set<Integer> ids) {
       List<ViewHistoryEntry> retainedHistory = Lists.newArrayList();
       for (ViewHistoryEntry entry : history) {
@@ -465,5 +529,29 @@ public interface ViewMetadata extends Serializable {
     private <U extends MetadataUpdate> Stream<U> changes(Class<U> updateClass) {
       return changes.stream().filter(updateClass::isInstance).map(updateClass::cast);
     }
+
+    private void checkIfDialectIsDropped(ViewVersion previous, ViewVersion current) {
+      Set<String> baseDialects = sqlDialectsFor(previous);
+      Set<String> updatedDialects = sqlDialectsFor(current);
+
+      Preconditions.checkState(
+          updatedDialects.containsAll(baseDialects),
+          "Cannot replace view due to loss of view dialects (%s=false):\nPrevious dialects: %s\nNew dialects: %s",
+          ViewProperties.REPLACE_DROP_DIALECT_ALLOWED,
+          baseDialects,
+          updatedDialects);
+    }
+
+    private Set<String> sqlDialectsFor(ViewVersion viewVersion) {
+      Set<String> dialects = Sets.newHashSet();
+      for (ViewRepresentation repr : viewVersion.representations()) {
+        if (repr instanceof SQLViewRepresentation) {
+          SQLViewRepresentation sql = (SQLViewRepresentation) repr;
+          dialects.add(sql.dialect().toLowerCase(Locale.ROOT));
+        }
+      }
+
+      return dialects;
+    }
   }
 }
