@@ -18,23 +18,23 @@
  */
 package org.apache.iceberg;
 
-import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Test;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestBaseIncrementalAppendScan
     extends ScanTestBase<IncrementalAppendScan, FileScanTask, CombinedScanTask> {
-  public TestBaseIncrementalAppendScan(int formatVersion) {
-    super(formatVersion);
-  }
 
   @Override
   protected IncrementalAppendScan newScan() {
     return table.newIncrementalAppendScan();
   }
 
-  @Test
+  @TestTemplate
   public void testFromSnapshotInclusive() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -44,21 +44,21 @@ public class TestBaseIncrementalAppendScan
     long snapshotCId = table.currentSnapshot().snapshotId();
 
     IncrementalAppendScan scan = newScan().fromSnapshotInclusive(snapshotAId);
-    Assert.assertEquals(3, Iterables.size(scan.planFiles()));
+    assertThat(scan.planFiles()).hasSize(3);
 
     IncrementalAppendScan scanWithToSnapshot =
         newScan().fromSnapshotInclusive(snapshotAId).toSnapshot(snapshotCId);
-    Assert.assertEquals(3, Iterables.size(scanWithToSnapshot.planFiles()));
+    assertThat(scanWithToSnapshot.planFiles()).hasSize(3);
   }
 
-  @Test
+  @TestTemplate
   public void fromSnapshotInclusiveWithNonExistingRef() {
-    Assertions.assertThatThrownBy(() -> newScan().fromSnapshotInclusive("nonExistingRef"))
+    assertThatThrownBy(() -> newScan().fromSnapshotInclusive("nonExistingRef"))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot find ref: nonExistingRef");
   }
 
-  @Test
+  @TestTemplate
   public void fromSnapshotInclusiveWithTag() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -77,31 +77,30 @@ public class TestBaseIncrementalAppendScan
      ---- snapshotAId(tag:t1) ---- snapshotMainB(tag:t2) ----  currentSnapshot
     */
     IncrementalAppendScan scan = newScan().fromSnapshotInclusive(tagSnapshotAName);
-    Assertions.assertThat(scan.planFiles()).hasSize(5);
+    assertThat(scan.planFiles()).hasSize(5);
 
     IncrementalAppendScan scanWithToSnapshot =
         newScan().fromSnapshotInclusive(tagSnapshotAName).toSnapshot(tagSnapshotBName);
-    Assertions.assertThat(scanWithToSnapshot.planFiles()).hasSize(3);
+    assertThat(scanWithToSnapshot.planFiles()).hasSize(3);
   }
 
-  @Test
+  @TestTemplate
   public void fromSnapshotInclusiveWithBranchShouldFail() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
 
     String branchName = "b1";
     table.manageSnapshots().createBranch(branchName, snapshotAId).commit();
-    Assertions.assertThatThrownBy(() -> newScan().fromSnapshotInclusive(branchName))
+    assertThatThrownBy(() -> newScan().fromSnapshotInclusive(branchName))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(String.format("Ref %s is not a tag", branchName));
 
-    Assertions.assertThatThrownBy(
-            () -> newScan().fromSnapshotInclusive(snapshotAId).toSnapshot(branchName))
+    assertThatThrownBy(() -> newScan().fromSnapshotInclusive(snapshotAId).toSnapshot(branchName))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(String.format("Ref %s is not a tag", branchName));
   }
 
-  @Test
+  @TestTemplate
   public void testUseBranch() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -138,40 +137,40 @@ public class TestBaseIncrementalAppendScan
                           snapshotBranchC(branch:b1)
     */
     IncrementalAppendScan scan = newScan().fromSnapshotInclusive(tagSnapshotAName);
-    Assertions.assertThat(scan.planFiles()).hasSize(5);
+    assertThat(scan.planFiles()).hasSize(5);
 
     IncrementalAppendScan scan2 =
         newScan().fromSnapshotInclusive(tagSnapshotAName).useBranch(branchName);
-    Assertions.assertThat(scan2.planFiles()).hasSize(3);
+    assertThat(scan2.planFiles()).hasSize(3);
 
     IncrementalAppendScan scan3 = newScan().toSnapshot(snapshotBranchBId).useBranch(branchName);
-    Assertions.assertThat(scan3.planFiles()).hasSize(2);
+    assertThat(scan3.planFiles()).hasSize(2);
 
     IncrementalAppendScan scan4 = newScan().toSnapshot(snapshotBranchCId).useBranch(branchName);
-    Assertions.assertThat(scan4.planFiles()).hasSize(3);
+    assertThat(scan4.planFiles()).hasSize(3);
 
     IncrementalAppendScan scan5 =
         newScan()
             .fromSnapshotExclusive(tagSnapshotAName)
             .toSnapshot(snapshotBranchBId)
             .useBranch(branchName);
-    Assertions.assertThat(scan5.planFiles()).hasSize(1);
+    assertThat(scan5.planFiles()).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void testUseBranchWithTagShouldFail() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
     String tagSnapshotAName = "t1";
     table.manageSnapshots().createTag(tagSnapshotAName, snapshotAId).commit();
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> newScan().fromSnapshotInclusive(snapshotAId).useBranch(tagSnapshotAName))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(String.format("Ref %s is not a branch", tagSnapshotAName));
   }
 
-  @Test
+  @TestTemplate
   public void testUseBranchWithInvalidSnapshotShouldFail() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -193,12 +192,12 @@ public class TestBaseIncrementalAppendScan
                           \files:FILE_C
                           snapshotBranchB(branch:b1)
     */
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> newScan().toSnapshot(snapshotMainBId).useBranch(branchName).planFiles())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("End snapshot is not a valid snapshot on the current branch");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 newScan().fromSnapshotInclusive(snapshotMainBId).useBranch(branchName).planFiles())
         .isInstanceOf(IllegalArgumentException.class)
@@ -208,14 +207,14 @@ public class TestBaseIncrementalAppendScan
                 snapshotMainBId, snapshotBranchBId));
   }
 
-  @Test
+  @TestTemplate
   public void testUseBranchWithNonExistingRef() {
-    Assertions.assertThatThrownBy(() -> newScan().useBranch("nonExistingRef"))
+    assertThatThrownBy(() -> newScan().useBranch("nonExistingRef"))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot find ref: nonExistingRef");
   }
 
-  @Test
+  @TestTemplate
   public void testFromSnapshotExclusive() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -225,14 +224,14 @@ public class TestBaseIncrementalAppendScan
     long snapshotCId = table.currentSnapshot().snapshotId();
 
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(snapshotAId);
-    Assert.assertEquals(2, Iterables.size(scan.planFiles()));
+    assertThat(scan.planFiles()).hasSize(2);
 
     IncrementalAppendScan scanWithToSnapshot =
         newScan().fromSnapshotExclusive(snapshotAId).toSnapshot(snapshotBId);
-    Assert.assertEquals(1, Iterables.size(scanWithToSnapshot.planFiles()));
+    assertThat(scanWithToSnapshot.planFiles()).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void testFromSnapshotExclusiveForExpiredParent() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -245,21 +244,21 @@ public class TestBaseIncrementalAppendScan
     table.expireSnapshots().expireOlderThan(expireTimestampSnapshotA).commit();
 
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(snapshotAId);
-    Assert.assertEquals(2, Iterables.size(scan.planFiles()));
+    assertThat(scan.planFiles()).hasSize(2);
 
     IncrementalAppendScan scanWithToSnapshot =
         newScan().fromSnapshotExclusive(snapshotAId).toSnapshot(snapshotBId);
-    Assert.assertEquals(1, Iterables.size(scanWithToSnapshot.planFiles()));
+    assertThat(scanWithToSnapshot.planFiles()).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void fromSnapshotExclusiveWithNonExistingRef() {
-    Assertions.assertThatThrownBy(() -> newScan().fromSnapshotExclusive("nonExistingRef"))
+    assertThatThrownBy(() -> newScan().fromSnapshotExclusive("nonExistingRef"))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot find ref: nonExistingRef");
   }
 
-  @Test
+  @TestTemplate
   public void testFromSnapshotExclusiveWithTag() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -278,26 +277,26 @@ public class TestBaseIncrementalAppendScan
      ---- snapshotAId(tag:t1) ---- snapshotMainB(tag:t2) ----  currentSnapshot
     */
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(tagSnapshotAName);
-    Assertions.assertThat(scan.planFiles()).hasSize(4);
+    assertThat(scan.planFiles()).hasSize(4);
 
     IncrementalAppendScan scanWithToSnapshot =
         newScan().fromSnapshotExclusive(tagSnapshotAName).toSnapshot(tagSnapshotBName);
-    Assertions.assertThat(scanWithToSnapshot.planFiles()).hasSize(2);
+    assertThat(scanWithToSnapshot.planFiles()).hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void fromSnapshotExclusiveWithBranchShouldFail() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
 
     String branchName = "b1";
     table.manageSnapshots().createBranch(branchName, snapshotAId).commit();
-    Assertions.assertThatThrownBy(() -> newScan().fromSnapshotExclusive(branchName))
+    assertThatThrownBy(() -> newScan().fromSnapshotExclusive(branchName))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(String.format("Ref %s is not a tag", branchName));
   }
 
-  @Test
+  @TestTemplate
   public void testToSnapshot() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -307,10 +306,10 @@ public class TestBaseIncrementalAppendScan
     long snapshotCId = table.currentSnapshot().snapshotId();
 
     IncrementalAppendScan scan = newScan().toSnapshot(snapshotBId);
-    Assert.assertEquals(2, Iterables.size(scan.planFiles()));
+    assertThat(scan.planFiles()).hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void testToSnapshotWithTag() {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -339,20 +338,20 @@ public class TestBaseIncrementalAppendScan
                                           snapshotBranchB(branch:b1, tag:t2)
     */
     IncrementalAppendScan scan = newScan().toSnapshot(tagSnapshotMainBName);
-    Assertions.assertThat(scan.planFiles()).hasSize(2);
+    assertThat(scan.planFiles()).hasSize(2);
 
     IncrementalAppendScan scan2 = newScan().toSnapshot(tagSnapshotBranchBName);
-    Assertions.assertThat(scan2.planFiles()).hasSize(3);
+    assertThat(scan2.planFiles()).hasSize(3);
   }
 
-  @Test
+  @TestTemplate
   public void testToSnapshotWithNonExistingRef() {
-    Assertions.assertThatThrownBy(() -> newScan().toSnapshot("nonExistingRef"))
+    assertThatThrownBy(() -> newScan().toSnapshot("nonExistingRef"))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot find ref: nonExistingRef");
   }
 
-  @Test
+  @TestTemplate
   public void testToSnapshotWithBranchShouldFail() {
     table.newFastAppend().appendFile(FILE_A).commit();
     table.newFastAppend().appendFile(FILE_B).commit();
@@ -361,12 +360,12 @@ public class TestBaseIncrementalAppendScan
     String branchName = "b1";
     table.manageSnapshots().createBranch(branchName, snapshotId).commit();
 
-    Assertions.assertThatThrownBy(() -> newScan().toSnapshot(branchName))
+    assertThatThrownBy(() -> newScan().toSnapshot(branchName))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(String.format("Ref %s is not a tag", branchName));
   }
 
-  @Test
+  @TestTemplate
   public void testMultipleRootSnapshots() throws Exception {
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
@@ -388,12 +387,12 @@ public class TestBaseIncrementalAppendScan
 
     // scan should discover snapshot C and D
     IncrementalAppendScan scan = newScan().toSnapshot(snapshotDId);
-    Assert.assertEquals(2, Iterables.size(scan.planFiles()));
+    assertThat(scan.planFiles()).hasSize(2);
 
     // scan should fail because snapshot B is not an ancestor of snapshot D
     IncrementalAppendScan scanShouldFail =
         newScan().fromSnapshotExclusive(snapshotBId).toSnapshot(snapshotDId);
-    Assertions.assertThatThrownBy(() -> Iterables.size(scanShouldFail.planFiles()))
+    assertThatThrownBy(() -> Iterables.size(scanShouldFail.planFiles()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(
             String.format(
@@ -403,7 +402,7 @@ public class TestBaseIncrementalAppendScan
     // scan should fail because snapshot B is not an ancestor of snapshot D
     IncrementalAppendScan scanShouldFailInclusive =
         newScan().fromSnapshotInclusive(snapshotBId).toSnapshot(snapshotDId);
-    Assertions.assertThatThrownBy(() -> Iterables.size(scanShouldFailInclusive.planFiles()))
+    assertThatThrownBy(() -> Iterables.size(scanShouldFailInclusive.planFiles()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(
             String.format(
