@@ -835,12 +835,12 @@ public class TestMetadataUpdateParser {
             .versionId(23)
             .timestampMillis(timestamp)
             .schemaId(4)
-            .putSummary("operation", "replace")
+            .putSummary("user", "some-user")
             .defaultNamespace(Namespace.of("ns"))
             .build();
     String json =
         String.format(
-            "{\"action\":\"%s\",\"view-version\":{\"version-id\":23,\"timestamp-ms\":123456789,\"schema-id\":4,\"summary\":{\"operation\":\"replace\"},\"default-namespace\":[\"ns\"],\"representations\":[]}}",
+            "{\"action\":\"%s\",\"view-version\":{\"version-id\":23,\"timestamp-ms\":123456789,\"schema-id\":4,\"summary\":{\"user\":\"some-user\"},\"default-namespace\":[\"ns\"],\"representations\":[]}}",
             action);
     MetadataUpdate expected = new MetadataUpdate.AddViewVersion(viewVersion);
     assertEquals(action, expected, MetadataUpdateParser.fromJson(json));
@@ -855,12 +855,12 @@ public class TestMetadataUpdateParser {
             .versionId(23)
             .timestampMillis(timestamp)
             .schemaId(4)
-            .putSummary("operation", "replace")
+            .putSummary("user", "some-user")
             .defaultNamespace(Namespace.of("ns"))
             .build();
     String expected =
         String.format(
-            "{\"action\":\"%s\",\"view-version\":{\"version-id\":23,\"timestamp-ms\":123456789,\"schema-id\":4,\"summary\":{\"operation\":\"replace\"},\"default-namespace\":[\"ns\"],\"representations\":[]}}",
+            "{\"action\":\"%s\",\"view-version\":{\"version-id\":23,\"timestamp-ms\":123456789,\"schema-id\":4,\"summary\":{\"user\":\"some-user\"},\"default-namespace\":[\"ns\"],\"representations\":[]}}",
             action);
 
     MetadataUpdate update = new MetadataUpdate.AddViewVersion(viewVersion);
@@ -884,6 +884,47 @@ public class TestMetadataUpdateParser {
     Assertions.assertThat(MetadataUpdateParser.toJson(update)).isEqualTo(expected);
   }
 
+  @Test
+  public void testSetPartitionStatistics() {
+    String json =
+        "{\"action\":\"set-partition-statistics\","
+            + "\"partition-statistics\":{\"snapshot-id\":1940541653261589030,"
+            + "\"statistics-path\":\"s3://bucket/warehouse/stats1.parquet\","
+            + "\"file-size-in-bytes\":43}}";
+
+    long snapshotId = 1940541653261589030L;
+    MetadataUpdate expected =
+        new MetadataUpdate.SetPartitionStatistics(
+            ImmutableGenericPartitionStatisticsFile.builder()
+                .snapshotId(snapshotId)
+                .path("s3://bucket/warehouse/stats1" + ".parquet")
+                .fileSizeInBytes(43L)
+                .build());
+    assertEquals(
+        MetadataUpdateParser.SET_PARTITION_STATISTICS,
+        expected,
+        MetadataUpdateParser.fromJson(json));
+    Assert.assertEquals(
+        "Set partition statistics should convert to the correct JSON value",
+        json,
+        MetadataUpdateParser.toJson(expected));
+  }
+
+  @Test
+  public void testRemovePartitionStatistics() {
+    String json =
+        "{\"action\":\"remove-partition-statistics\",\"snapshot-id\":1940541653261589030}";
+    MetadataUpdate expected = new MetadataUpdate.RemovePartitionStatistics(1940541653261589030L);
+    assertEquals(
+        MetadataUpdateParser.REMOVE_PARTITION_STATISTICS,
+        expected,
+        MetadataUpdateParser.fromJson(json));
+    Assert.assertEquals(
+        "Remove partition statistics should convert to the correct JSON value",
+        json,
+        MetadataUpdateParser.toJson(expected));
+  }
+
   public void assertEquals(
       String action, MetadataUpdate expectedUpdate, MetadataUpdate actualUpdate) {
     switch (action) {
@@ -935,6 +976,16 @@ public class TestMetadataUpdateParser {
             (MetadataUpdate.RemoveStatistics) expectedUpdate,
             (MetadataUpdate.RemoveStatistics) actualUpdate);
         break;
+      case MetadataUpdateParser.SET_PARTITION_STATISTICS:
+        assertEqualsSetPartitionStatistics(
+            (MetadataUpdate.SetPartitionStatistics) expectedUpdate,
+            (MetadataUpdate.SetPartitionStatistics) actualUpdate);
+        break;
+      case MetadataUpdateParser.REMOVE_PARTITION_STATISTICS:
+        assertEqualsRemovePartitionStatistics(
+            (MetadataUpdate.RemovePartitionStatistics) expectedUpdate,
+            (MetadataUpdate.RemovePartitionStatistics) actualUpdate);
+        break;
       case MetadataUpdateParser.ADD_SNAPSHOT:
         assertEqualsAddSnapshot(
             (MetadataUpdate.AddSnapshot) expectedUpdate, (MetadataUpdate.AddSnapshot) actualUpdate);
@@ -1134,6 +1185,31 @@ public class TestMetadataUpdateParser {
         "Snapshots to remove should be the same", expected.snapshotId(), actual.snapshotId());
   }
 
+  private static void assertEqualsSetPartitionStatistics(
+      MetadataUpdate.SetPartitionStatistics expected,
+      MetadataUpdate.SetPartitionStatistics actual) {
+    Assert.assertEquals("Snapshot IDs should be equal", expected.snapshotId(), actual.snapshotId());
+    Assert.assertEquals(
+        "Partition Statistics files snapshot IDs should be equal",
+        expected.partitionStatisticsFile().snapshotId(),
+        actual.partitionStatisticsFile().snapshotId());
+    Assert.assertEquals(
+        "Partition statistics files paths should be equal",
+        expected.partitionStatisticsFile().path(),
+        actual.partitionStatisticsFile().path());
+    Assert.assertEquals(
+        "Partition statistics file size should be equal",
+        expected.partitionStatisticsFile().fileSizeInBytes(),
+        actual.partitionStatisticsFile().fileSizeInBytes());
+  }
+
+  private static void assertEqualsRemovePartitionStatistics(
+      MetadataUpdate.RemovePartitionStatistics expected,
+      MetadataUpdate.RemovePartitionStatistics actual) {
+    Assert.assertEquals(
+        "Snapshots to remove should be the same", expected.snapshotId(), actual.snapshotId());
+  }
+
   private static void assertEqualsAddSnapshot(
       MetadataUpdate.AddSnapshot expected, MetadataUpdate.AddSnapshot actual) {
     Assert.assertEquals(
