@@ -29,10 +29,12 @@ import java.util.Set;
 import org.apache.iceberg.FileScanTask;
 import org.apache.iceberg.HasTableOperations;
 import org.apache.iceberg.MetadataTableType;
+import org.apache.iceberg.MetadataTableUtils;
 import org.apache.iceberg.PositionDeletesScanTask;
 import org.apache.iceberg.PositionDeletesTable;
 import org.apache.iceberg.ScanTask;
 import org.apache.iceberg.SerializableTable;
+import org.apache.iceberg.StaticTableOperations;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.TestHelpers;
@@ -43,6 +45,8 @@ import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
 import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 public class TestTableSerialization extends HadoopTableTestBase {
 
@@ -58,6 +62,9 @@ public class TestTableSerialization extends HadoopTableTestBase {
     Table serializableTable = SerializableTable.copyOf(table);
     TestHelpers.assertSerializedAndLoadedMetadata(
         serializableTable, TestHelpers.KryoHelpers.roundTripSerialize(serializableTable));
+    Assertions.assertThat(serializableTable).isInstanceOf(HasTableOperations.class);
+    Assertions.assertThat(((HasTableOperations) serializableTable).operations())
+        .isInstanceOf(StaticTableOperations.class);
   }
 
   @Test
@@ -118,16 +125,19 @@ public class TestTableSerialization extends HadoopTableTestBase {
     Assertions.assertThat(deserializedFiles).isNotEqualTo(getFiles(table));
   }
 
-  @Test
-  public void testSerializableMetadataTablesPlanning() throws IOException {
+  @ParameterizedTest
+  @ValueSource(booleans = {true, false})
+  public void testSerializableMetadataTablesPlanning(boolean fromSerialized) throws IOException {
     table.updateProperties().set(TableProperties.FORMAT_VERSION, "2").commit();
-
     table.newAppend().appendFile(FILE_A).commit();
 
+    Table sourceTable =
+        fromSerialized ? (SerializableTable) SerializableTable.copyOf(table) : table;
+
     Map<MetadataTableType, byte[]> serialized = Maps.newHashMap();
     Map<MetadataTableType, Set<CharSequence>> expected = Maps.newHashMap();
     for (MetadataTableType type : MetadataTableType.values()) {
-      Table metaTable = getMetaDataTable(table, type);
+      Table metaTable = MetadataTableUtils.createMetadataTableInstance(sourceTable, type);
       // Serialize the table
       serialized.put(type, serializeToBytes(metaTable));
 
@@ -153,6 +163,22 @@ public class TestTableSerialization extends HadoopTableTestBase {
     }
   }
 
+  @Test
+  public void testMetadataTableFromSerializedTable() {
+    table.newAppend().appendFile(FILE_A).commit();
+
+    SerializableTable serializableTable = (SerializableTable) SerializableTable.copyOf(table);
+
+    Table metaFromOriginal =
+        MetadataTableUtils.createMetadataTableInstance(table, MetadataTableType.ENTRIES);
+    Table metaFromSerializable =
+        MetadataTableUtils.createMetadataTableInstance(
+            serializableTable, MetadataTableType.ENTRIES);
+
+    // Check that the data is correct
+    TestHelpers.assertSerializedAndLoadedMetadata(metaFromOriginal, metaFromSerializable);
+  }
+
   private static Table getMetaDataTable(Table table, MetadataTableType type) {
     return TABLES.load(
         ((HasTableOperations) table).operations().current().metadataFileLocation() + "#" + type);
