@@ -91,8 +91,7 @@ public class TestFlinkCatalogTablePartitions extends CatalogTestBase {
     FlinkCatalog flinkCatalog = (FlinkCatalog) getTableEnv().getCatalog(catalogName).get();
     Assertions.assertThatThrownBy(() -> flinkCatalog.listPartitions(objectPath))
         .isInstanceOf(TableNotPartitionedException.class)
-        .hasMessageStartingWith("Table db.test_table in catalog")
-        .hasMessageEndingWith("is not partitioned.");
+        .hasMessage("Table " + objectPath + " in catalog " + catalogName + " is not partitioned.");
   }
 
   @TestTemplate
