@@ -42,7 +42,7 @@ public class TestFlinkHiveCatalog extends FlinkTestBase {
     Map<String, String> props = Maps.newHashMap();
     props.put("type", "iceberg");
     props.put(FlinkCatalogFactory.ICEBERG_CATALOG_TYPE, "hive");
-    props.put(CatalogProperties.URI, FlinkCatalogTestBase.getURI(hiveConf));
+    props.put(CatalogProperties.URI, CatalogTestBase.getURI(hiveConf));
 
     File warehouseDir = tempFolder.newFolder();
     props.put(CatalogProperties.WAREHOUSE_LOCATION, "file://" + warehouseDir.getAbsolutePath());
@@ -69,7 +69,7 @@ public class TestFlinkHiveCatalog extends FlinkTestBase {
     Map<String, String> props = Maps.newHashMap();
     props.put("type", "iceberg");
     props.put(FlinkCatalogFactory.ICEBERG_CATALOG_TYPE, "hive");
-    props.put(CatalogProperties.URI, FlinkCatalogTestBase.getURI(hiveConf));
+    props.put(CatalogProperties.URI, CatalogTestBase.getURI(hiveConf));
     // Set the 'hive-conf-dir' instead of 'warehouse'
     props.put(FlinkCatalogFactory.HIVE_CONF_DIR, hiveConfDir.getAbsolutePath());
 
@@ -78,9 +78,7 @@ public class TestFlinkHiveCatalog extends FlinkTestBase {
 
   private void checkSQLQuery(Map<String, String> catalogProperties, File warehouseDir)
       throws IOException {
-    sql(
-        "CREATE CATALOG test_catalog WITH %s",
-        FlinkCatalogTestBase.toWithClause(catalogProperties));
+    sql("CREATE CATALOG test_catalog WITH %s", CatalogTestBase.toWithClause(catalogProperties));
     sql("USE CATALOG test_catalog");
     sql("CREATE DATABASE test_db");
     sql("USE test_db");
