@@ -91,7 +91,9 @@ public class HiveTableTest extends HiveTableBaseTest {
     // Table should be renamed in hive metastore
     String tableName = TABLE_IDENTIFIER.name();
     org.apache.hadoop.hive.metastore.api.Table table =
-        metastoreClient.getTable(TABLE_IDENTIFIER.namespace().level(0), tableName);
+        HIVE_METASTORE_EXTENSION
+            .metastoreClient()
+            .getTable(TABLE_IDENTIFIER.namespace().level(0), tableName);
 
     // check parameters are in expected state
     Map<String, String> parameters = table.getParameters();
@@ -255,7 +257,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     assertThat(icebergTable.schema().asStruct()).isEqualTo(altered.asStruct());
 
     final org.apache.hadoop.hive.metastore.api.Table table =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
     final List<String> hiveColumns =
         table.getSd().getCols().stream().map(FieldSchema::getName).collect(Collectors.toList());
     final List<String> icebergColumns =
@@ -309,10 +311,10 @@ public class HiveTableTest extends HiveTableBaseTest {
   public void testFailure() throws TException {
     Table icebergTable = catalog.loadTable(TABLE_IDENTIFIER);
     org.apache.hadoop.hive.metastore.api.Table table =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
     String dummyLocation = "dummylocation";
     table.getParameters().put(METADATA_LOCATION_PROP, dummyLocation);
-    metastoreClient.alter_table(DB_NAME, TABLE_NAME, table);
+    HIVE_METASTORE_EXTENSION.metastoreClient().alter_table(DB_NAME, TABLE_NAME, table);
     assertThatThrownBy(
             () -> icebergTable.updateSchema().addColumn("data", Types.LongType.get()).commit())
         .isInstanceOf(CommitFailedException.class)
@@ -333,7 +335,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     // create a hive table
     String hiveTableName = "test_hive_table";
     org.apache.hadoop.hive.metastore.api.Table hiveTable = createHiveTable(hiveTableName);
-    metastoreClient.createTable(hiveTable);
+    HIVE_METASTORE_EXTENSION.metastoreClient().createTable(hiveTable);
 
     catalog.setListAllTables(false);
     List<TableIdentifier> tableIdents1 = catalog.listTables(TABLE_IDENTIFIER.namespace());
@@ -344,7 +346,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     assertThat(tableIdents2).as("should be 2 tables in namespace .").hasSize(2);
 
     assertThat(catalog.tableExists(TABLE_IDENTIFIER)).isTrue();
-    metastoreClient.dropTable(DB_NAME, hiveTableName);
+    HIVE_METASTORE_EXTENSION.metastoreClient().dropTable(DB_NAME, hiveTableName);
   }
 
   private org.apache.hadoop.hive.metastore.api.Table createHiveTable(String hiveTableName)
@@ -410,13 +412,13 @@ public class HiveTableTest extends HiveTableBaseTest {
     assertThat(table.location()).isEqualTo(namespaceMeta.get("location") + "/" + TABLE_NAME);
 
     // Drop the database and purge the files
-    metastoreClient.dropDatabase(NON_DEFAULT_DATABASE, true, true, true);
+    HIVE_METASTORE_EXTENSION.metastoreClient().dropDatabase(NON_DEFAULT_DATABASE, true, true, true);
   }
 
   @Test
   public void testRegisterTable() throws TException {
     org.apache.hadoop.hive.metastore.api.Table originalTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     Map<String, String> originalParams = originalTable.getParameters();
     assertThat(originalParams).isNotNull();
@@ -432,7 +434,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     catalog.registerTable(TABLE_IDENTIFIER, "file:" + metadataVersionFiles.get(0));
 
     org.apache.hadoop.hive.metastore.api.Table newTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     Map<String, String> newTableParameters = newTable.getParameters();
     assertThat(newTableParameters)
@@ -466,7 +468,7 @@ public class HiveTableTest extends HiveTableBaseTest {
             .collect(Collectors.toList());
     assertThat(metadataFiles).hasSize(2);
 
-    assertThatThrownBy(() -> metastoreClient.getTable(DB_NAME, "table1"))
+    assertThatThrownBy(() -> HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, "table1"))
         .isInstanceOf(NoSuchObjectException.class)
         .hasMessage("hivedb.table1 table not found");
     assertThatThrownBy(() -> catalog.loadTable(identifier))
@@ -476,7 +478,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     // register the table to hive catalog using the latest metadata file
     String latestMetadataFile = ((BaseTable) table).operations().current().metadataFileLocation();
     catalog.registerTable(identifier, "file:" + latestMetadataFile);
-    assertThat(metastoreClient.getTable(DB_NAME, "table1")).isNotNull();
+    assertThat(HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, "table1")).isNotNull();
 
     // load the table in hive catalog
     table = catalog.loadTable(identifier);
@@ -523,7 +525,7 @@ public class HiveTableTest extends HiveTableBaseTest {
   @Test
   public void testRegisterExistingTable() throws TException {
     org.apache.hadoop.hive.metastore.api.Table originalTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     Map<String, String> originalParams = originalTable.getParameters();
     assertThat(originalParams).isNotNull();
@@ -550,7 +552,7 @@ public class HiveTableTest extends HiveTableBaseTest {
 
     catalog.createTable(TABLE_IDENTIFIER, schema, PartitionSpec.unpartitioned());
     org.apache.hadoop.hive.metastore.api.Table hmsTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     assertHiveEnabled(hmsTable, false);
   }
@@ -565,7 +567,7 @@ public class HiveTableTest extends HiveTableBaseTest {
 
     catalog.createTable(TABLE_IDENTIFIER, schema, PartitionSpec.unpartitioned());
     org.apache.hadoop.hive.metastore.api.Table hmsTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     assertHiveEnabled(hmsTable, true);
 
@@ -575,7 +577,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     catalog.getConf().set(ConfigProperties.ENGINE_HIVE_ENABLED, "false");
 
     catalog.createTable(TABLE_IDENTIFIER, schema, PartitionSpec.unpartitioned());
-    hmsTable = metastoreClient.getTable(DB_NAME, TABLE_NAME);
+    hmsTable = HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     assertHiveEnabled(hmsTable, false);
   }
@@ -592,7 +594,7 @@ public class HiveTableTest extends HiveTableBaseTest {
 
     catalog.createTable(TABLE_IDENTIFIER, schema, PartitionSpec.unpartitioned(), tableProperties);
     org.apache.hadoop.hive.metastore.api.Table hmsTable =
-        metastoreClient.getTable(DB_NAME, TABLE_NAME);
+        HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     assertHiveEnabled(hmsTable, true);
 
@@ -603,7 +605,7 @@ public class HiveTableTest extends HiveTableBaseTest {
     catalog.getConf().set(ConfigProperties.ENGINE_HIVE_ENABLED, "true");
 
     catalog.createTable(TABLE_IDENTIFIER, schema, PartitionSpec.unpartitioned(), tableProperties);
-    hmsTable = metastoreClient.getTable(DB_NAME, TABLE_NAME);
+    hmsTable = HIVE_METASTORE_EXTENSION.metastoreClient().getTable(DB_NAME, TABLE_NAME);
 
     assertHiveEnabled(hmsTable, false);
   }
