@@ -19,6 +19,7 @@
 package org.apache.iceberg.mr.hive;
 
 import static org.apache.iceberg.types.Types.NestedField.optional;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.IOException;
@@ -63,7 +64,6 @@ import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.ByteBuffers;
-import org.junit.Assert;
 
 public class HiveIcebergTestUtils {
   // TODO: Can this be a constant all around the Iceberg tests?
@@ -218,13 +218,10 @@ public class HiveIcebergTestUtils {
     for (int i = 0; i < expected.size(); ++i) {
       if (expected.get(i) instanceof OffsetDateTime) {
         // For OffsetDateTime we just compare the actual instant
-        Assert.assertEquals(
-            ((OffsetDateTime) expected.get(i)).toInstant(),
-            ((OffsetDateTime) actual.get(i)).toInstant());
-      } else if (expected.get(i) instanceof byte[]) {
-        Assert.assertArrayEquals((byte[]) expected.get(i), (byte[]) actual.get(i));
+        assertThat(((OffsetDateTime) actual.get(i)).toInstant())
+            .isEqualTo(((OffsetDateTime) expected.get(i)).toInstant());
       } else {
-        Assert.assertEquals(expected.get(i), actual.get(i));
+        assertThat(actual.get(i)).isEqualTo(expected.get(i));
       }
     }
   }
@@ -265,7 +262,7 @@ public class HiveIcebergTestUtils {
     sortedExpected.sort(Comparator.comparingLong(record -> (Long) record.get(sortBy)));
     sortedActual.sort(Comparator.comparingLong(record -> (Long) record.get(sortBy)));
 
-    Assert.assertEquals(sortedExpected.size(), sortedActual.size());
+    assertThat(sortedActual).hasSameSizeAs(sortedExpected);
     for (int i = 0; i < sortedExpected.size(); ++i) {
       assertEquals(sortedExpected.get(i), sortedActual.get(i));
     }
@@ -288,9 +285,9 @@ public class HiveIcebergTestUtils {
             .filter(path -> !path.getFileName().toString().startsWith("."))
             .collect(Collectors.toList());
 
-    Assert.assertEquals(dataFileNum, dataFiles.size());
-    Assert.assertFalse(
-        new File(HiveIcebergOutputCommitter.generateJobLocation(table.location(), conf, jobId))
-            .exists());
+    assertThat(dataFiles).hasSize(dataFileNum);
+    assertThat(
+            new File(HiveIcebergOutputCommitter.generateJobLocation(table.location(), conf, jobId)))
+        .doesNotExist();
   }
 }
