@@ -18,9 +18,12 @@
  */
 package org.apache.iceberg.mr.hive;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.io.File;
 import java.io.IOException;
-import java.io.UncheckedIOException;
+import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.sql.Timestamp;
 import java.time.LocalDateTime;
 import java.time.OffsetDateTime;
@@ -57,11 +60,8 @@ import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.apache.iceberg.relocated.com.google.common.collect.ObjectArrays;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
-import org.junit.Assert;
-import org.junit.rules.TemporaryFolder;
 
 // Helper class for setting up and testing various catalog implementations
 abstract class TestTables {
@@ -74,16 +74,16 @@ abstract class TestTables {
       };
 
   private final Tables tables;
-  protected final TemporaryFolder temp;
+  protected final Path temp;
   protected final String catalog;
 
-  protected TestTables(Tables tables, TemporaryFolder temp, String catalogName) {
+  protected TestTables(Tables tables, Path temp, String catalogName) {
     this.tables = tables;
     this.temp = temp;
     this.catalog = catalogName;
   }
 
-  protected TestTables(Catalog catalog, TemporaryFolder temp, String catalogName) {
+  protected TestTables(Catalog catalog, Path temp, String catalogName) {
     this(new CatalogToTables(catalog), temp, catalogName);
   }
 
@@ -417,18 +417,17 @@ abstract class TestTables {
 
     private final String warehouseLocation;
 
-    CustomCatalogTestTables(Configuration conf, TemporaryFolder temp, String catalogName)
-        throws IOException {
+    CustomCatalogTestTables(Configuration conf, Path temp, String catalogName) throws IOException {
       this(
           conf,
           temp,
           (HiveVersion.min(HiveVersion.HIVE_3) ? "file:" : "")
-              + temp.newFolder("custom", "warehouse").toString(),
+              + temp.resolve(Paths.get("custom", "warehouse")),
           catalogName);
     }
 
     CustomCatalogTestTables(
-        Configuration conf, TemporaryFolder temp, String warehouseLocation, String catalogName) {
+        Configuration conf, Path temp, String warehouseLocation, String catalogName) {
       super(new TestCatalogs.CustomHadoopCatalog(conf, warehouseLocation), temp, catalogName);
       this.warehouseLocation = warehouseLocation;
     }
@@ -452,18 +451,17 @@ abstract class TestTables {
 
     private final String warehouseLocation;
 
-    HadoopCatalogTestTables(Configuration conf, TemporaryFolder temp, String catalogName)
-        throws IOException {
+    HadoopCatalogTestTables(Configuration conf, Path temp, String catalogName) throws IOException {
       this(
           conf,
           temp,
           (HiveVersion.min(HiveVersion.HIVE_3) ? "file:" : "")
-              + temp.newFolder("hadoop", "warehouse").toString(),
+              + temp.resolve(Paths.get("hadoop", "warehouse")),
           catalogName);
     }
 
     HadoopCatalogTestTables(
-        Configuration conf, TemporaryFolder temp, String warehouseLocation, String catalogName) {
+        Configuration conf, Path temp, String warehouseLocation, String catalogName) {
       super(new HadoopCatalog(conf, warehouseLocation), temp, catalogName);
       this.warehouseLocation = warehouseLocation;
     }
@@ -484,7 +482,8 @@ abstract class TestTables {
   }
 
   static class HadoopTestTables extends TestTables {
-    HadoopTestTables(Configuration conf, TemporaryFolder temp) {
+
+    HadoopTestTables(Configuration conf, Path temp) {
       super(new HadoopTables(conf), temp, Catalogs.ICEBERG_HADOOP_TABLE_NAME);
     }
 
@@ -492,32 +491,32 @@ abstract class TestTables {
     public String identifier(String tableIdentifier) {
       final File location;
 
-      try {
-        TableIdentifier identifier = TableIdentifier.parse(tableIdentifier);
-        location =
-            temp.newFolder(ObjectArrays.concat(identifier.namespace().levels(), identifier.name()));
-      } catch (IOException ioe) {
-        throw new UncheckedIOException(ioe);
-      }
+      TableIdentifier identifier = TableIdentifier.parse(tableIdentifier);
+      location =
+          temp.resolve(
+                  Joiner.on(File.separator).join(identifier.namespace().levels())
+                      + File.separator
+                      + identifier.name())
+              .toFile();
 
-      Assert.assertTrue(location.delete());
+      assertThat(location).doesNotExist();
       return location.toString();
     }
 
     @Override
     public String locationForCreateTableSQL(TableIdentifier identifier) {
-      return "LOCATION '" + temp.getRoot().getPath() + tablePath(identifier) + "' ";
+      return "LOCATION '" + temp + tablePath(identifier) + "' ";
     }
 
     @Override
     public Table loadTable(TableIdentifier identifier) {
-      return tables().load(temp.getRoot().getPath() + TestTables.tablePath(identifier));
+      return tables().load(temp + TestTables.tablePath(identifier));
     }
   }
 
   static class HiveTestTables extends TestTables {
 
-    HiveTestTables(Configuration conf, TemporaryFolder temp, String catalogName) {
+    HiveTestTables(Configuration conf, Path temp, String catalogName) {
       super(
           CatalogUtil.loadCatalog(
               HiveCatalog.class.getName(),
@@ -569,36 +568,32 @@ abstract class TestTables {
   enum TestTableType {
     HADOOP_TABLE {
       @Override
-      public TestTables instance(
-          Configuration conf, TemporaryFolder temporaryFolder, String catalogName) {
+      public TestTables instance(Configuration conf, Path temporaryFolder, String catalogName) {
         return new HadoopTestTables(conf, temporaryFolder);
       }
     },
     HADOOP_CATALOG {
       @Override
-      public TestTables instance(
-          Configuration conf, TemporaryFolder temporaryFolder, String catalogName)
+      public TestTables instance(Configuration conf, Path temporaryFolder, String catalogName)
           throws IOException {
         return new HadoopCatalogTestTables(conf, temporaryFolder, catalogName);
       }
     },
     CUSTOM_CATALOG {
       @Override
-      public TestTables instance(
-          Configuration conf, TemporaryFolder temporaryFolder, String catalogName)
+      public TestTables instance(Configuration conf, Path temporaryFolder, String catalogName)
           throws IOException {
         return new CustomCatalogTestTables(conf, temporaryFolder, catalogName);
       }
     },
     HIVE_CATALOG {
       @Override
-      public TestTables instance(
-          Configuration conf, TemporaryFolder temporaryFolder, String catalogName) {
+      public TestTables instance(Configuration conf, Path temporaryFolder, String catalogName) {
         return new HiveTestTables(conf, temporaryFolder, catalogName);
       }
     };
 
     public abstract TestTables instance(
-        Configuration conf, TemporaryFolder temporaryFolder, String catalogName) throws IOException;
+        Configuration conf, Path temporaryFolder, String catalogName) throws IOException;
   }
 }
