@@ -39,16 +39,17 @@ import static org.apache.iceberg.expressions.Expressions.startsWith;
 import static org.apache.iceberg.expressions.Expressions.truncate;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.apache.parquet.column.ParquetProperties.WriterVersion.PARQUET_1_0;
-import static org.apache.parquet.column.ParquetProperties.WriterVersion.PARQUET_2_0;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.math.RoundingMode;
+import java.nio.file.Path;
 import java.util.Arrays;
-import java.util.List;
+import java.util.Collection;
 import java.util.NoSuchElementException;
 import java.util.UUID;
 import java.util.stream.Collectors;
@@ -56,8 +57,10 @@ import java.util.stream.IntStream;
 import org.apache.avro.generic.GenericData.Record;
 import org.apache.avro.generic.GenericRecordBuilder;
 import org.apache.iceberg.Files;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Schema;
-import org.apache.iceberg.TestHelpers;
 import org.apache.iceberg.avro.AvroSchemaUtil;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expression;
@@ -79,15 +82,12 @@ import org.apache.parquet.hadoop.metadata.BlockMetaData;
 import org.apache.parquet.hadoop.metadata.ColumnChunkMetaData;
 import org.apache.parquet.hadoop.metadata.ColumnPath;
 import org.apache.parquet.schema.MessageType;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestDictionaryRowGroupFilter {
 
   private static final Types.StructType structFieldType =
@@ -156,22 +156,18 @@ public class TestDictionaryRowGroupFilter {
   private MessageType parquetSchema = null;
   private BlockMetaData rowGroupMetadata = null;
   private DictionaryPageReadStore dictionaryStore = null;
-  private final WriterVersion writerVersion;
+  @Parameter private WriterVersion writerVersion;
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
-
-  @Parameterized.Parameters
-  public static List<WriterVersion> writerVersions() {
-    return Arrays.asList(PARQUET_1_0, PARQUET_2_0);
+  @Parameters(name = "writerVersion={0}")
+  public static Collection<WriterVersion> parameters() {
+    return Arrays.asList(WriterVersion.PARQUET_1_0, WriterVersion.PARQUET_2_0);
   }
 
-  public TestDictionaryRowGroupFilter(WriterVersion writerVersion) {
-    this.writerVersion = writerVersion;
-  }
+  @TempDir private Path temp;
 
-  @Before
+  @BeforeEach
   public void createInputFile() throws IOException {
-    File parquetFile = temp.newFile();
+    File parquetFile = temp.toFile();
     assertThat(parquetFile.delete()).isTrue();
 
     // build struct field schema
@@ -223,52 +219,33 @@ public class TestDictionaryRowGroupFilter {
     dictionaryStore = reader.getNextDictionaryReader();
   }
 
-  @Test
+  @TestTemplate
   public void testAssumptions() {
     // this case validates that other cases don't need to test expressions with null literals.
-    TestHelpers.assertThrows(
-        "Should reject null literal in equal expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> equal("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in notEqual expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> notEqual("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in lessThan expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> lessThan("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in lessThanOrEqual expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> lessThanOrEqual("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in greaterThan expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> greaterThan("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in greaterThanOrEqual expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> greaterThanOrEqual("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in startsWith expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> startsWith("col", null));
-    TestHelpers.assertThrows(
-        "Should reject null literal in notStartsWith expression",
-        NullPointerException.class,
-        "Cannot create expression literal from null",
-        () -> notStartsWith("col", null));
+    assertThatThrownBy(() -> equal("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> notEqual("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> lessThan("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> lessThanOrEqual("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> greaterThan("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> startsWith("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
+    assertThatThrownBy(() -> notStartsWith("col", null))
+        .isInstanceOf(NullPointerException.class)
+        .hasMessageContaining("Cannot create expression literal from null");
   }
 
-  @Test
+  @TestTemplate
   public void testAllNulls() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notNull("all_nulls"))
@@ -291,7 +268,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: dictionary filter doesn't help").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testNoNulls() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, isNull("all_nulls"))
@@ -314,7 +291,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: dictionary filter doesn't help").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testRequiredColumn() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notNull("required"))
@@ -327,7 +304,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: required columns are always non-null").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testIsNaNs() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, isNaN("all_nans"))
@@ -345,7 +322,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: no_nans column will not contain NaN").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testNotNaNs() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notNaN("all_nans"))
@@ -363,7 +340,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: no_nans column will contain non-NaN").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testNotNaNOnNaNsAndNulls() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, isNull("_nans_and_nulls"))
@@ -394,7 +371,7 @@ public class TestDictionaryRowGroupFilter {
         .isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStartsWith() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, startsWith("non_dict", "re"))
@@ -438,7 +415,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: no match in dictionary").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testNotStartsWith() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notStartsWith("non_dict", "re"))
@@ -487,18 +464,17 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: dictionary contains a matching entry").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testMissingColumn() {
-    TestHelpers.assertThrows(
-        "Should complain about missing column in expression",
-        ValidationException.class,
-        "Cannot find field 'missing'",
-        () ->
-            new ParquetDictionaryRowGroupFilter(SCHEMA, lessThan("missing", 5))
-                .shouldRead(parquetSchema, rowGroupMetadata, dictionaryStore));
+    assertThatThrownBy(
+            () ->
+                new ParquetDictionaryRowGroupFilter(SCHEMA, lessThan("missing", 5))
+                    .shouldRead(parquetSchema, rowGroupMetadata, dictionaryStore))
+        .hasMessageContaining("Cannot find field 'missing'")
+        .isInstanceOf(ValidationException.class);
   }
 
-  @Test
+  @TestTemplate
   public void testColumnNotInFile() {
     Expression[] exprs =
         new Expression[] {
@@ -516,7 +492,7 @@ public class TestDictionaryRowGroupFilter {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testColumnFallbackOrNotDictionaryEncoded() {
     Expression[] exprs =
         new Expression[] {
@@ -533,7 +509,7 @@ public class TestDictionaryRowGroupFilter {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testMissingStats() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, equal("no_stats", "a"))
@@ -541,7 +517,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: stats are missing but dictionary is present").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testNot() {
     // this test case must use a real predicate, not alwaysTrue(), or binding will simplify it out
     boolean shouldRead =
@@ -555,7 +531,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: not(true)").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testAnd() {
     // this test case must use a real predicate, not alwaysTrue(), or binding will simplify it out
     boolean shouldRead =
@@ -584,7 +560,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: and(true, true)").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testOr() {
     // this test case must use a real predicate, not alwaysTrue(), or binding will simplify it out
     boolean shouldRead =
@@ -604,7 +580,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: or(false, true)").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerLt() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, lessThan("id", INT_MIN_VALUE - 25))
@@ -629,7 +605,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerLtEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, lessThanOrEqual("id", INT_MIN_VALUE - 25))
@@ -652,7 +628,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: many possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerGt() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, greaterThan("id", INT_MAX_VALUE + 6))
@@ -677,7 +653,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerGtEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, greaterThanOrEqual("id", INT_MAX_VALUE + 6))
@@ -700,7 +676,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, equal("id", INT_MIN_VALUE - 25))
@@ -738,7 +714,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should not read: id above upper bound").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerNotEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notEqual("id", INT_MIN_VALUE - 25))
@@ -776,7 +752,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: id above upper bound").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerNotEqRewritten() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, not(equal("id", INT_MIN_VALUE - 25)))
@@ -814,7 +790,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: id above upper bound").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStringNotEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notEqual("some_nulls", "some"))
@@ -827,7 +803,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: contains only ''").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldLt() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -856,7 +832,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldLtEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -883,7 +859,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: many possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldGt() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -912,7 +888,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldGtEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -939,7 +915,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: may possible ids").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -984,7 +960,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should not read: id above upper bound").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testStructFieldNotEq() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -1028,7 +1004,7 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should read: id above upper bound").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testCaseInsensitive() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, notEqual("no_Nulls", ""), false)
@@ -1036,18 +1012,17 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should skip: contains only ''").isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testMissingDictionaryPageForColumn() {
-    TestHelpers.assertThrows(
-        "Should complain about missing dictionary",
-        IllegalStateException.class,
-        "Failed to read required dictionary page for id: 5",
-        () ->
-            new ParquetDictionaryRowGroupFilter(SCHEMA, notEqual("some_nulls", "some"))
-                .shouldRead(parquetSchema, rowGroupMetadata, descriptor -> null));
+    assertThatThrownBy(
+            () ->
+                new ParquetDictionaryRowGroupFilter(SCHEMA, notEqual("some_nulls", "some"))
+                    .shouldRead(parquetSchema, rowGroupMetadata, descriptor -> null))
+        .isInstanceOf(IllegalStateException.class)
+        .hasMessageContaining("Failed to read required dictionary page for id: 5");
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerIn() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -1147,7 +1122,7 @@ public class TestDictionaryRowGroupFilter {
         .isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testIntegerNotIn() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
@@ -1250,7 +1225,7 @@ public class TestDictionaryRowGroupFilter {
         .isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testTypePromotion() {
     Schema promotedSchema = new Schema(required(1, "id", LongType.get()));
     boolean shouldRead =
@@ -1259,18 +1234,14 @@ public class TestDictionaryRowGroupFilter {
     assertThat(shouldRead).as("Should succeed with promoted schema").isTrue();
   }
 
-  @Test
+  @TestTemplate
   public void testFixedLenByteArray() {
     // This test is to validate the handling of FIXED_LEN_BYTE_ARRAY Parquet type being dictionary
     // encoded.
     // (No need to validate all the possible predicates)
 
-    Assume.assumeTrue(
-        "decimal_fixed is not dictionary encoded in case of writer version " + writerVersion,
-        getColumnForName(rowGroupMetadata, "_decimal_fixed")
-            .getEncodings()
-            .contains(Encoding.RLE_DICTIONARY));
-
+    assumeThat(getColumnForName(rowGroupMetadata, "_decimal_fixed").getEncodings())
+        .contains(Encoding.RLE_DICTIONARY);
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(
                 SCHEMA, greaterThanOrEqual("decimal_fixed", BigDecimal.ZERO))
@@ -1287,7 +1258,7 @@ public class TestDictionaryRowGroupFilter {
         .isFalse();
   }
 
-  @Test
+  @TestTemplate
   public void testTransformFilter() {
     boolean shouldRead =
         new ParquetDictionaryRowGroupFilter(SCHEMA, equal(truncate("required", 2), "some_value"))
