@@ -20,23 +20,16 @@ package org.apache.iceberg.spark.extensions;
 
 import static org.apache.iceberg.DataOperations.DELETE;
 import static org.apache.iceberg.DataOperations.OVERWRITE;
-import static org.apache.iceberg.PlanningMode.DISTRIBUTED;
-import static org.apache.iceberg.PlanningMode.LOCAL;
 import static org.apache.iceberg.SnapshotSummary.ADDED_DELETE_FILES_PROP;
 import static org.apache.iceberg.SnapshotSummary.ADDED_FILES_PROP;
 import static org.apache.iceberg.SnapshotSummary.CHANGED_PARTITION_COUNT_PROP;
 import static org.apache.iceberg.SnapshotSummary.DELETED_FILES_PROP;
-import static org.apache.iceberg.TableProperties.DATA_PLANNING_MODE;
 import static org.apache.iceberg.TableProperties.DEFAULT_FILE_FORMAT;
-import static org.apache.iceberg.TableProperties.DELETE_PLANNING_MODE;
-import static org.apache.iceberg.TableProperties.ORC_VECTORIZATION_ENABLED;
 import static org.apache.iceberg.TableProperties.PARQUET_VECTORIZATION_ENABLED;
-import static org.apache.iceberg.TableProperties.SPARK_WRITE_PARTITIONED_FANOUT_ENABLED;
 import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE;
 import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE_HASH;
 import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE_NONE;
 import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE_RANGE;
-import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.IOException;
 import java.io.UncheckedIOException;
@@ -48,10 +41,7 @@ import java.util.Set;
 import java.util.concurrent.ThreadLocalRandom;
 import java.util.stream.Collectors;
 import org.apache.iceberg.DataFile;
-import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Files;
-import org.apache.iceberg.PlanningMode;
-import org.apache.iceberg.RowLevelOperationMode;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.SnapshotRef;
 import org.apache.iceberg.Table;
@@ -68,7 +58,6 @@ import org.apache.spark.sql.Encoder;
 import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
-import org.apache.spark.sql.execution.SparkPlan;
 import org.junit.Assert;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
@@ -82,9 +71,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
   protected final String fileFormat;
   protected final boolean vectorized;
   protected final String distributionMode;
-  protected final boolean fanoutEnabled;
   protected final String branch;
-  protected final PlanningMode planningMode;
 
   public SparkRowLevelOperationsTestBase(
       String catalogName,
@@ -93,23 +80,18 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
       String fileFormat,
       boolean vectorized,
       String distributionMode,
-      boolean fanoutEnabled,
-      String branch,
-      PlanningMode planningMode) {
+      String branch) {
     super(catalogName, implementation, config);
     this.fileFormat = fileFormat;
     this.vectorized = vectorized;
     this.distributionMode = distributionMode;
-    this.fanoutEnabled = fanoutEnabled;
     this.branch = branch;
-    this.planningMode = planningMode;
   }
 
   @Parameters(
       name =
           "catalogName = {0}, implementation = {1}, config = {2},"
-              + " format = {3}, vectorized = {4}, distributionMode = {5},"
-              + " fanout = {6}, branch = {7}, planningMode = {8}")
+              + " format = {3}, vectorized = {4}, distributionMode = {5}, branch = {6}")
   public static Object[][] parameters() {
     return new Object[][] {
       {
@@ -121,9 +103,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
         "orc",
         true,
         WRITE_DISTRIBUTION_MODE_NONE,
-        true,
-        SnapshotRef.MAIN_BRANCH,
-        LOCAL
+        SnapshotRef.MAIN_BRANCH
       },
       {
         "testhive",
@@ -134,9 +114,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
         "parquet",
         true,
         WRITE_DISTRIBUTION_MODE_NONE,
-        false,
         "test",
-        DISTRIBUTED
       },
       {
         "testhadoop",
@@ -145,9 +123,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
         "parquet",
         RANDOM.nextBoolean(),
         WRITE_DISTRIBUTION_MODE_HASH,
-        true,
-        null,
-        LOCAL
+        null
       },
       {
         "spark_catalog",
@@ -163,9 +139,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
         "avro",
         false,
         WRITE_DISTRIBUTION_MODE_RANGE,
-        false,
-        "test",
-        DISTRIBUTED
+        "test"
       }
     };
   }
@@ -173,19 +147,10 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
   protected abstract Map<String, String> extraTableProperties();
 
   protected void initTable() {
+    sql("ALTER TABLE %s SET TBLPROPERTIES('%s' '%s')", tableName, DEFAULT_FILE_FORMAT, fileFormat);
     sql(
-        "ALTER TABLE %s SET TBLPROPERTIES('%s' '%s', '%s' '%s', '%s' '%s', '%s' '%s', '%s' '%s')",
-        tableName,
-        DEFAULT_FILE_FORMAT,
-        fileFormat,
-        WRITE_DISTRIBUTION_MODE,
-        distributionMode,
-        SPARK_WRITE_PARTITIONED_FANOUT_ENABLED,
-        String.valueOf(fanoutEnabled),
-        DATA_PLANNING_MODE,
-        planningMode.modeName(),
-        DELETE_PLANNING_MODE,
-        planningMode.modeName());
+        "ALTER TABLE %s SET TBLPROPERTIES('%s' '%s')",
+        tableName, WRITE_DISTRIBUTION_MODE, distributionMode);
 
     switch (fileFormat) {
       case "parquet":
@@ -194,9 +159,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
             tableName, PARQUET_VECTORIZATION_ENABLED, vectorized);
         break;
       case "orc":
-        sql(
-            "ALTER TABLE %s SET TBLPROPERTIES('%s' '%b')",
-            tableName, ORC_VECTORIZATION_ENABLED, vectorized);
+        Assert.assertTrue(vectorized);
         break;
       case "avro":
         Assert.assertFalse(vectorized);
@@ -262,7 +225,7 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
   private Dataset<Row> toDS(String schema, String jsonData) {
     List<String> jsonRows =
         Arrays.stream(jsonData.split("\n"))
-            .filter(str -> str.trim().length() > 0)
+            .filter(str -> !str.trim().isEmpty())
             .collect(Collectors.toList());
     Dataset<String> jsonDS = spark.createDataset(jsonRows, Encoders.STRING());
 
@@ -377,22 +340,4 @@ public abstract class SparkRowLevelOperationsTestBase extends SparkExtensionsTes
       sql("ALTER TABLE %s CREATE BRANCH %s", tableName, branch);
     }
   }
-
-  // ORC currently does not support vectorized reads with deletes
-  protected boolean supportsVectorization() {
-    return vectorized && (isParquet() || isCopyOnWrite());
-  }
-
-  private boolean isParquet() {
-    return fileFormat.equalsIgnoreCase(FileFormat.PARQUET.name());
-  }
-
-  private boolean isCopyOnWrite() {
-    return extraTableProperties().containsValue(RowLevelOperationMode.COPY_ON_WRITE.modeName());
-  }
-
-  protected void assertAllBatchScansVectorized(SparkPlan plan) {
-    List<SparkPlan> batchScans = SparkPlanUtil.collectBatchScans(plan);
-    assertThat(batchScans).hasSizeGreaterThan(0).allMatch(SparkPlan::supportsColumnar);
-  }
 }
