@@ -57,7 +57,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.FileRewriteCoordinator;
 import org.apache.iceberg.spark.SparkWriteConf;
-import org.apache.iceberg.spark.SparkWriteRequirements;
 import org.apache.spark.TaskContext;
 import org.apache.spark.TaskContext$;
 import org.apache.spark.api.java.JavaSparkContext;
@@ -99,8 +98,8 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
   private final StructType dsSchema;
   private final Map<String, String> extraSnapshotMetadata;
   private final boolean partitionedFanoutEnabled;
-  private final SparkWriteRequirements writeRequirements;
-  private final Map<String, String> writeProperties;
+  private final Distribution requiredDistribution;
+  private final SortOrder[] requiredOrdering;
 
   private boolean cleanupOnAbort = true;
 
@@ -112,7 +111,8 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       String applicationId,
       Schema writeSchema,
       StructType dsSchema,
-      SparkWriteRequirements writeRequirements) {
+      Distribution requiredDistribution,
+      SortOrder[] requiredOrdering) {
     this.sparkContext = JavaSparkContext.fromSparkContext(spark.sparkContext());
     this.table = table;
     this.writeConf = writeConf;
@@ -127,24 +127,19 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     this.dsSchema = dsSchema;
     this.extraSnapshotMetadata = writeConf.extraSnapshotMetadata();
     this.partitionedFanoutEnabled = writeConf.fanoutWriterEnabled();
-    this.writeRequirements = writeRequirements;
+    this.requiredDistribution = requiredDistribution;
+    this.requiredOrdering = requiredOrdering;
     this.outputSpecId = writeConf.outputSpecId();
-    this.writeProperties = writeConf.writeProperties();
   }
 
   @Override
   public Distribution requiredDistribution() {
-    return writeRequirements.distribution();
-  }
-
-  @Override
-  public boolean distributionStrictlyRequired() {
-    return false;
+    return requiredDistribution;
   }
 
   @Override
   public SortOrder[] requiredOrdering() {
-    return writeRequirements.ordering();
+    return requiredOrdering;
   }
 
   BatchWrite asBatchAppend() {
@@ -188,8 +183,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         targetFileSize,
         writeSchema,
         dsSchema,
-        partitionedFanoutEnabled,
-        writeProperties);
+        partitionedFanoutEnabled);
   }
 
   private void commitOperation(SnapshotUpdate<?> operation, String description) {
@@ -260,11 +254,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       return createWriterFactory();
     }
 
-    @Override
-    public boolean useCommitCoordinator() {
-      return false;
-    }
-
     @Override
     public void abort(WriterCommitMessage[] messages) {
       SparkWrite.this.abort(messages);
@@ -624,7 +613,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     private final StructType dsSchema;
     private final boolean partitionedFanoutEnabled;
     private final String queryId;
-    private final Map<String, String> writeProperties;
 
     protected WriterFactory(
         Broadcast<Table> tableBroadcast,
@@ -634,8 +622,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         long targetFileSize,
         Schema writeSchema,
         StructType dsSchema,
-        boolean partitionedFanoutEnabled,
-        Map<String, String> writeProperties) {
+        boolean partitionedFanoutEnabled) {
       this.tableBroadcast = tableBroadcast;
       this.format = format;
       this.outputSpecId = outputSpecId;
@@ -644,7 +631,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       this.dsSchema = dsSchema;
       this.partitionedFanoutEnabled = partitionedFanoutEnabled;
       this.queryId = queryId;
-      this.writeProperties = writeProperties;
     }
 
     @Override
@@ -668,7 +654,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
               .dataFileFormat(format)
               .dataSchema(writeSchema)
               .dataSparkType(dsSchema)
-              .writeProperties(writeProperties)
               .build();
 
       if (spec.isUnpartitioned()) {
