@@ -19,11 +19,11 @@
 package org.apache.iceberg.spark.extensions;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
-import java.nio.file.Path;
+import java.io.IOException;
 import java.util.List;
+import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -35,9 +35,6 @@ import org.apache.avro.generic.GenericDatumWriter;
 import org.apache.avro.generic.GenericRecord;
 import org.apache.avro.io.DatumWriter;
 import org.apache.iceberg.DataFile;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
@@ -52,15 +49,17 @@ import org.apache.spark.sql.types.StructField;
 import org.apache.spark.sql.types.StructType;
 import org.assertj.core.api.Assertions;
 import org.joda.time.DateTime;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Disabled;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
-import org.junit.jupiter.api.io.TempDir;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Assume;
+import org.junit.Before;
+import org.junit.Ignore;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import org.junit.runners.Parameterized.Parameters;
 
-@ExtendWith(ParameterizedTestExtension.class)
-public class TestAddFilesProcedure extends ExtensionsTestBase {
+public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
   @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, formatVersion = {3}")
   public static Object[][] parameters() {
@@ -86,26 +85,34 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
     };
   }
 
-  @Parameter(index = 3)
-  private int formatVersion;
-
+  private final int formatVersion;
   private final String sourceTableName = "source_table";
   private File fileTableDir;
 
-  @TempDir private Path temp;
-
-  @BeforeEach
-  public void setupTempDirs() {
-    fileTableDir = temp.toFile();
+  public TestAddFilesProcedure(
+      String catalogName, String implementation, Map<String, String> config, int formatVersion) {
+    super(catalogName, implementation, config);
+    this.formatVersion = formatVersion;
   }
 
-  @AfterEach
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
+
+  @Before
+  public void setupTempDirs() {
+    try {
+      fileTableDir = temp.newFolder();
+    } catch (IOException e) {
+      throw new RuntimeException(e);
+    }
+  }
+
+  @After
   public void dropTables() {
     sql("DROP TABLE IF EXISTS %s PURGE", sourceTableName);
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
+  @Test
   public void addDataUnpartitioned() {
     createUnpartitionedFileTable("parquet");
 
@@ -124,7 +131,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void deleteAndAddBackUnpartitioned() {
     createUnpartitionedFileTable("parquet");
 
@@ -150,7 +157,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @Disabled // TODO Classpath issues prevent us from actually writing to a Spark ORC table
+  @Ignore // TODO Classpath issues prevent us from actually writing to a Spark ORC table
   public void addDataUnpartitionedOrc() {
     createUnpartitionedFileTable("orc");
 
@@ -164,7 +171,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             "CALL %s.system.add_files('%s', '`orc`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    assertThat(result).isEqualTo(2L);
+    Assert.assertEquals(2L, result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -172,11 +179,11 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addAvroFile() throws Exception {
     // Spark Session Catalog cannot load metadata tables
     // with "The namespace in session catalog must have exactly one name part"
-    assumeThat(catalogName).isNotEqualTo("spark_catalog");
+    Assume.assumeFalse(catalogName.equals("spark_catalog"));
 
     // Create an Avro file
 
@@ -192,7 +199,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
     GenericRecord record2 = new GenericData.Record(schema);
     record2.put("id", 2L);
     record2.put("data", "b");
-    File outputFile = temp.resolve("test.avro").toFile();
+    File outputFile = temp.newFile("test.avro");
 
     DatumWriter<GenericRecord> datumWriter = new GenericDatumWriter(schema);
     DataFileWriter<GenericRecord> dataFileWriter = new DataFileWriter(datumWriter);
@@ -227,7 +234,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
   }
 
   // TODO Adding spark-avro doesn't work in tests
-  @Disabled
+  @Ignore
   public void addDataUnpartitionedAvro() {
     createUnpartitionedFileTable("avro");
 
@@ -241,7 +248,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             "CALL %s.system.add_files('%s', '`avro`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    assertThat(result).isEqualTo(2L);
+    Assert.assertEquals(2L, result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -249,7 +256,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataUnpartitionedHive() {
     createUnpartitionedHiveTable();
 
@@ -266,7 +273,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataUnpartitionedExtraCol() {
     createUnpartitionedFileTable("parquet");
 
@@ -285,7 +292,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataUnpartitionedMissingCol() {
     createUnpartitionedFileTable("parquet");
 
@@ -304,7 +311,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataPartitionedMissingCol() {
     createPartitionedFileTable("parquet");
 
@@ -323,7 +330,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataPartitioned() {
     createPartitionedFileTable("parquet");
 
@@ -343,7 +350,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @Disabled // TODO Classpath issues prevent us from actually writing to a Spark ORC table
+  @Ignore // TODO Classpath issues prevent us from actually writing to a Spark ORC table
   public void addDataPartitionedOrc() {
     createPartitionedFileTable("orc");
 
@@ -357,7 +364,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    assertThat(result).isEqualTo(8L);
+    Assert.assertEquals(8L, result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -366,7 +373,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
   }
 
   // TODO Adding spark-avro doesn't work in tests
-  @Disabled
+  @Ignore
   public void addDataPartitionedAvro() {
     createPartitionedFileTable("avro");
 
@@ -380,7 +387,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             "CALL %s.system.add_files('%s', '`avro`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    assertThat(result).isEqualTo(8L);
+    Assert.assertEquals(8L, result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -388,7 +395,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataPartitionedHive() {
     createPartitionedHiveTable();
 
@@ -406,7 +413,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addPartitionToPartitioned() {
     createPartitionedFileTable("parquet");
 
@@ -426,7 +433,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void deleteAndAddBackPartitioned() {
     createPartitionedFileTable("parquet");
 
@@ -453,7 +460,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addPartitionToPartitionedSnapshotIdInheritanceEnabledInTwoRuns() {
     createPartitionedFileTable("parquet");
 
@@ -482,10 +489,10 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
     Pattern uuidPattern = Pattern.compile("[a-f0-9]{8}(?:-[a-f0-9]{4}){4}[a-f0-9]{8}");
 
     Matcher matcher = uuidPattern.matcher(manifestPath);
-    assertThat(matcher.find()).as("verify manifest path has uuid").isTrue();
+    Assert.assertTrue("verify manifest path has uuid", matcher.find());
   }
 
-  @TestTemplate
+  @Test
   public void addDataPartitionedByDateToPartitioned() {
     createDatePartitionedFileTable("parquet");
 
@@ -504,7 +511,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, date FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addDataPartitionedVerifyPartitionTypeInferredCorrectly() {
     createTableWithTwoPartitions("parquet");
 
@@ -523,7 +530,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql(sqlFormat, tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addFilteredPartitionsToPartitioned() {
     createCompositePartitionedTable("parquet");
 
@@ -543,7 +550,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addFilteredPartitionsToPartitioned2() {
     createCompositePartitionedTable("parquet");
 
@@ -565,7 +572,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addFilteredPartitionsToPartitionedWithNullValueFilteringOnId() {
     createCompositePartitionedTableWithNullValueInPartitionColumn("parquet");
 
@@ -585,7 +592,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addFilteredPartitionsToPartitionedWithNullValueFilteringOnDept() {
     createCompositePartitionedTableWithNullValueInPartitionColumn("parquet");
 
@@ -607,7 +614,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addWeirdCaseHiveTable() {
     createWeirdCaseTable();
 
@@ -632,20 +639,22 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             .collect(Collectors.toList());
 
     // TODO when this assert breaks Spark fixed the pushdown issue
-    assertThat(
-            sql(
+    Assert.assertEquals(
+        "If this assert breaks it means that Spark has fixed the pushdown issue",
+        0,
+        sql(
                 "SELECT id, `naMe`, dept, subdept from %s WHERE `naMe` = 'John Doe' ORDER BY id",
-                sourceTableName))
-        .as("If this assert breaks it means that Spark has fixed the pushdown issue")
-        .hasSize(0);
+                sourceTableName)
+            .size());
 
     // Pushdown works for iceberg
-    assertThat(
-            sql(
+    Assert.assertEquals(
+        "We should be able to pushdown mixed case partition keys",
+        2,
+        sql(
                 "SELECT id, `naMe`, dept, subdept FROM %s WHERE `naMe` = 'John Doe' ORDER BY id",
-                tableName))
-        .as("We should be able to pushdown mixed case partition keys")
-        .hasSize(2);
+                tableName)
+            .size());
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -653,7 +662,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, `naMe`, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void addPartitionToPartitionedHive() {
     createPartitionedHiveTable();
 
@@ -673,7 +682,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void invalidDataImport() {
     createPartitionedFileTable("parquet");
 
@@ -696,7 +705,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         .hasMessageStartingWith("Cannot add partitioned files to an unpartitioned table");
   }
 
-  @TestTemplate
+  @Test
   public void invalidDataImportPartitioned() {
     createUnpartitionedFileTable("parquet");
 
@@ -723,7 +732,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
             "specified partition filter refers to columns that are not partitioned");
   }
 
-  @TestTemplate
+  @Test
   public void addTwice() {
     createPartitionedHiveTable();
 
@@ -758,7 +767,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s WHERE id = 2 ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void duplicateDataPartitioned() {
     createPartitionedHiveTable();
 
@@ -786,7 +795,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
                 + " exist within the target table");
   }
 
-  @TestTemplate
+  @Test
   public void duplicateDataPartitionedAllowed() {
     createPartitionedHiveTable();
 
@@ -823,7 +832,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT id, name, dept, subdept FROM %s", tableName, tableName));
   }
 
-  @TestTemplate
+  @Test
   public void duplicateDataUnpartitioned() {
     createUnpartitionedHiveTable();
 
@@ -842,7 +851,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
                 + " exist within the target table");
   }
 
-  @TestTemplate
+  @Test
   public void duplicateDataUnpartitionedAllowed() {
     createUnpartitionedHiveTable();
 
@@ -869,7 +878,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testEmptyImportDoesNotThrow() {
     createIcebergTable("id Integer, name String, dept String, subdept String");
 
@@ -898,7 +907,7 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedImportFromEmptyPartitionDoesNotThrow() {
     createPartitionedHiveTable();
 
@@ -926,28 +935,6 @@ public class TestAddFilesProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
-  public void testAddFilesWithParallelism() {
-    createUnpartitionedHiveTable();
-
-    String createIceberg =
-        "CREATE TABLE %s (id Integer, name String, dept String, subdept String) USING iceberg";
-
-    sql(createIceberg, tableName);
-
-    List<Object[]> result =
-        sql(
-            "CALL %s.system.add_files(table => '%s', source_table => '%s', parallelism => 2)",
-            catalogName, tableName, sourceTableName);
-
-    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
-
-    assertEquals(
-        "Iceberg table contains correct data",
-        sql("SELECT * FROM %s ORDER BY id", sourceTableName),
-        sql("SELECT * FROM %s ORDER BY id", tableName));
-  }
-
   private static final List<Object[]> emptyQueryResult = Lists.newArrayList();
 
   private static final StructField[] struct = {
