@@ -23,7 +23,6 @@ import static org.assertj.core.api.Assertions.assertThat;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
-import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.SnapshotRef;
 import org.apache.iceberg.Table;
@@ -86,11 +85,10 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxSnapshotAge), ref.maxSnapshotAgeMs().longValue());
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxRefAge), ref.maxRefAgeMs().longValue());
 
-    AssertHelpers.assertThrows(
-        "Cannot create an existing branch",
-        IllegalArgumentException.class,
-        "Ref b1 already exists",
-        () -> sql("ALTER TABLE %s CREATE BRANCH %s", tableName, branchName));
+    Assertions.assertThatThrownBy(
+            () -> sql("ALTER TABLE %s CREATE BRANCH %s", tableName, branchName))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Ref b1 already exists");
   }
 
   @Test
@@ -196,12 +194,13 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxSnapshotAge), ref.maxSnapshotAgeMs().longValue());
     Assert.assertNull(ref.maxRefAgeMs());
 
-    AssertHelpers.assertThrows(
-        "Illegal statement",
-        IcebergParseException.class,
-        "no viable alternative at input 'WITH SNAPSHOT RETENTION'",
-        () ->
-            sql("ALTER TABLE %s CREATE BRANCH %s WITH SNAPSHOT RETENTION", tableName, branchName));
+    Assertions.assertThatThrownBy(
+            () ->
+                sql(
+                    "ALTER TABLE %s CREATE BRANCH %s WITH SNAPSHOT RETENTION",
+                    tableName, branchName))
+        .isInstanceOf(IcebergParseException.class)
+        .hasMessageContaining("no viable alternative at input 'WITH SNAPSHOT RETENTION'");
   }
 
   @Test
@@ -217,26 +216,24 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertNull(ref.maxSnapshotAgeMs());
     Assert.assertEquals(TimeUnit.DAYS.toMillis(maxRefAge), ref.maxRefAgeMs().longValue());
 
-    AssertHelpers.assertThrows(
-        "Illegal statement",
-        IcebergParseException.class,
-        "mismatched input",
-        () -> sql("ALTER TABLE %s CREATE BRANCH %s RETAIN", tableName, branchName));
+    Assertions.assertThatThrownBy(
+            () -> sql("ALTER TABLE %s CREATE BRANCH %s RETAIN", tableName, branchName))
+        .isInstanceOf(IcebergParseException.class)
+        .hasMessageContaining("mismatched input");
 
-    AssertHelpers.assertThrows(
-        "Illegal statement",
-        IcebergParseException.class,
-        "mismatched input",
-        () -> sql("ALTER TABLE %s CREATE BRANCH %s RETAIN %s DAYS", tableName, branchName, "abc"));
+    Assertions.assertThatThrownBy(
+            () ->
+                sql("ALTER TABLE %s CREATE BRANCH %s RETAIN %s DAYS", tableName, branchName, "abc"))
+        .isInstanceOf(IcebergParseException.class)
+        .hasMessageContaining("mismatched input");
 
-    AssertHelpers.assertThrows(
-        "Illegal statement",
-        IcebergParseException.class,
-        "mismatched input 'SECONDS' expecting {'DAYS', 'HOURS', 'MINUTES'}",
-        () ->
-            sql(
-                "ALTER TABLE %s CREATE BRANCH %s RETAIN %d SECONDS",
-                tableName, branchName, maxRefAge));
+    Assertions.assertThatThrownBy(
+            () ->
+                sql(
+                    "ALTER TABLE %s CREATE BRANCH %s RETAIN %d SECONDS",
+                    tableName, branchName, maxRefAge))
+        .isInstanceOf(IcebergParseException.class)
+        .hasMessageContaining("mismatched input 'SECONDS' expecting {'DAYS', 'HOURS', 'MINUTES'}");
   }
 
   @Test
@@ -258,11 +255,10 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
 
   @Test
   public void testDropBranchDoesNotExist() {
-    AssertHelpers.assertThrows(
-        "Cannot perform drop branch on branch which does not exist",
-        IllegalArgumentException.class,
-        "Branch does not exist: nonExistingBranch",
-        () -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "nonExistingBranch"));
+    Assertions.assertThatThrownBy(
+            () -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "nonExistingBranch"))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Branch does not exist: nonExistingBranch");
   }
 
   @Test
@@ -271,29 +267,23 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Table table = insertRows();
     table.manageSnapshots().createTag(tagName, table.currentSnapshot().snapshotId()).commit();
 
-    AssertHelpers.assertThrows(
-        "Cannot perform drop branch on tag",
-        IllegalArgumentException.class,
-        "Ref b1 is a tag not a branch",
-        () -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, tagName));
+    Assertions.assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, tagName))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Ref b1 is a tag not a branch");
   }
 
   @Test
   public void testDropBranchNonConformingName() {
-    AssertHelpers.assertThrows(
-        "Non-conforming branch name",
-        IcebergParseException.class,
-        "mismatched input '123'",
-        () -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "123"));
+    Assertions.assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH %s", tableName, "123"))
+        .isInstanceOf(IcebergParseException.class)
+        .hasMessageContaining("mismatched input '123'");
   }
 
   @Test
   public void testDropMainBranchFails() {
-    AssertHelpers.assertThrows(
-        "Cannot drop the main branch",
-        IllegalArgumentException.class,
-        "Cannot remove main branch",
-        () -> sql("ALTER TABLE %s DROP BRANCH main", tableName));
+    Assertions.assertThatThrownBy(() -> sql("ALTER TABLE %s DROP BRANCH main", tableName))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Cannot remove main branch");
   }
 
   @Test
@@ -309,6 +299,14 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
     Assert.assertNull(ref);
   }
 
+  private Table insertRows() throws NoSuchTableException {
+    List<SimpleRecord> records =
+        ImmutableList.of(new SimpleRecord(1, "a"), new SimpleRecord(2, "b"));
+    Dataset<Row> df = spark.createDataFrame(records, SimpleRecord.class);
+    df.writeTo(tableName).append();
+    return validationCatalog.loadTable(tableIdent);
+  }
+
   @Test
   public void createOrReplace() throws NoSuchTableException {
     Table table = insertRows();
@@ -396,12 +394,4 @@ public class TestBranchDDL extends SparkExtensionsTestBase {
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Branch does not exist: someBranch");
   }
-
-  private Table insertRows() throws NoSuchTableException {
-    List<SimpleRecord> records =
-        ImmutableList.of(new SimpleRecord(1, "a"), new SimpleRecord(2, "b"));
-    Dataset<Row> df = spark.createDataFrame(records, SimpleRecord.class);
-    df.writeTo(tableName).append();
-    return validationCatalog.loadTable(tableIdent);
-  }
 }
