@@ -33,7 +33,6 @@ import org.assertj.core.api.Assertions;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
-import org.junit.Ignore;
 import org.junit.Test;
 
 public class TestDropTable extends SparkCatalogTestBase {
@@ -86,8 +85,7 @@ public class TestDropTable extends SparkCatalogTestBase {
     }
   }
 
-  // TODO: enable once SPARK-43203 is fixed
-  @Ignore
+  @Test
   public void testPurgeTable() throws IOException {
     assertEquals(
         "Should have expected rows",
@@ -104,8 +102,7 @@ public class TestDropTable extends SparkCatalogTestBase {
     Assert.assertTrue("All files should be deleted", checkFilesExist(manifestAndFiles, false));
   }
 
-  // TODO: enable once SPARK-43203 is fixed
-  @Ignore
+  @Test
   public void testPurgeTableGCDisabled() throws IOException {
     sql("ALTER TABLE %s SET TBLPROPERTIES (gc.enabled = false)", tableName);
 
