@@ -21,11 +21,15 @@ package org.apache.iceberg.spark.source;
 import static org.apache.iceberg.spark.SparkSchemaUtil.convert;
 import static org.apache.iceberg.spark.data.TestHelpers.assertEqualsSafe;
 import static org.apache.iceberg.spark.data.TestHelpers.assertEqualsUnsafe;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
 import java.io.IOException;
 import java.net.URI;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -33,6 +37,9 @@ import java.util.Random;
 import org.apache.avro.generic.GenericData.Record;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.Files;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Snapshot;
@@ -47,7 +54,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.SparkSQLProperties;
 import org.apache.iceberg.spark.SparkSchemaUtil;
 import org.apache.iceberg.spark.SparkWriteOptions;
-import org.apache.iceberg.spark.data.AvroDataTest;
+import org.apache.iceberg.spark.data.ParameterizedAvroDataTest;
 import org.apache.iceberg.spark.data.RandomData;
 import org.apache.iceberg.spark.data.SparkAvroReader;
 import org.apache.iceberg.types.Types;
@@ -63,29 +70,21 @@ import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SaveMode;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.InternalRow;
-import org.assertj.core.api.Assertions;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
-public class TestDataFrameWrites extends AvroDataTest {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestDataFrameWrites extends ParameterizedAvroDataTest {
   private static final Configuration CONF = new Configuration();
 
-  private final String format;
-
-  @Parameterized.Parameters(name = "format = {0}")
-  public static Object[] parameters() {
-    return new Object[] {"parquet", "avro", "orc"};
+  @Parameters(name = "format = {0}")
+  public static Collection<String> parameters() {
+    return Arrays.asList("parquet", "avro", "orc");
   }
 
-  public TestDataFrameWrites(String format) {
-    this.format = format;
-  }
+  @Parameter private String format;
 
   private static SparkSession spark = null;
   private static JavaSparkContext sc = null;
@@ -123,13 +122,13 @@ public class TestDataFrameWrites extends AvroDataTest {
           "{\"optionalField\": \"d3\", \"requiredField\": \"bid_103\"}",
           "{\"optionalField\": \"d4\", \"requiredField\": \"bid_104\"}");
 
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
     TestDataFrameWrites.spark = SparkSession.builder().master("local[2]").getOrCreate();
     TestDataFrameWrites.sc = JavaSparkContext.fromSparkContext(spark.sparkContext());
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestDataFrameWrites.spark;
     TestDataFrameWrites.spark = null;
@@ -144,10 +143,10 @@ public class TestDataFrameWrites extends AvroDataTest {
     writeAndValidateWithLocations(table, location, new File(location, "data"));
   }
 
-  @Test
+  @TestTemplate
   public void testWriteWithCustomDataLocation() throws IOException {
     File location = createTableFolder();
-    File tablePropertyDataLocation = temp.newFolder("test-table-property-data-dir");
+    File tablePropertyDataLocation = temp.resolve("test-table-property-data-dir").toFile();
     Table table = createTable(new Schema(SUPPORTED_PRIMITIVES.fields()), location);
     table
         .updateProperties()
@@ -157,9 +156,9 @@ public class TestDataFrameWrites extends AvroDataTest {
   }
 
   private File createTableFolder() throws IOException {
-    File parent = temp.newFolder("parquet");
+    File parent = temp.resolve("parquet").toFile();
     File location = new File(parent, "test");
-    Assert.assertTrue("Mkdir should succeed", location.mkdirs());
+    assertThat(location.mkdirs()).as("Mkdir should succeed").isTrue();
     return location;
   }
 
@@ -186,21 +185,21 @@ public class TestDataFrameWrites extends AvroDataTest {
     while (expectedIter.hasNext() && actualIter.hasNext()) {
       assertEqualsSafe(tableSchema.asStruct(), expectedIter.next(), actualIter.next());
     }
-    Assert.assertEquals(
-        "Both iterators should be exhausted", expectedIter.hasNext(), actualIter.hasNext());
+    assertThat(actualIter.hasNext())
+        .as("Both iterators should be exhausted")
+        .isEqualTo(expectedIter.hasNext());
 
     table
         .currentSnapshot()
         .addedDataFiles(table.io())
         .forEach(
             dataFile ->
-                Assert.assertTrue(
-                    String.format(
-                        "File should have the parent directory %s, but has: %s.",
-                        expectedDataDir.getAbsolutePath(), dataFile.path()),
-                    URI.create(dataFile.path().toString())
-                        .getPath()
-                        .startsWith(expectedDataDir.getAbsolutePath())));
+                assertThat(URI.create(dataFile.path().toString()).getPath())
+                    .as(
+                        String.format(
+                            "File should have the parent directory %s, but has: %s.",
+                            expectedDataDir.getAbsolutePath(), dataFile.path()))
+                    .startsWith(expectedDataDir.getAbsolutePath()));
   }
 
   private List<Row> readTable(String location) {
@@ -247,8 +246,8 @@ public class TestDataFrameWrites extends AvroDataTest {
   private Dataset<Row> createDataset(Iterable<Record> records, Schema schema) throws IOException {
     // this uses the SparkAvroReader to create a DataFrame from the list of records
     // it assumes that SparkAvroReader is correct
-    File testFile = temp.newFile();
-    Assert.assertTrue("Delete should succeed", testFile.delete());
+    File testFile = File.createTempFile("junit", null, temp.toFile());
+    assertThat(testFile.delete()).as("Delete should succeed").isTrue();
 
     try (FileAppender<Record> writer =
         Avro.write(Files.localOutput(testFile)).schema(schema).named("test").build()) {
@@ -272,20 +271,22 @@ public class TestDataFrameWrites extends AvroDataTest {
         assertEqualsUnsafe(schema.asStruct(), recordIter.next(), row);
         rows.add(row);
       }
-      Assert.assertEquals(
-          "Both iterators should be exhausted", recordIter.hasNext(), readIter.hasNext());
+      assertThat(readIter.hasNext())
+          .as("Both iterators should be exhausted")
+          .isEqualTo(recordIter.hasNext());
     }
 
     JavaRDD<InternalRow> rdd = sc.parallelize(rows);
     return spark.internalCreateDataFrame(JavaRDD.toRDD(rdd), convert(schema), false);
   }
 
-  @Test
+  @TestTemplate
   public void testNullableWithWriteOption() throws IOException {
-    Assume.assumeTrue(
-        "Spark 3 rejects writing nulls to a required column", spark.version().startsWith("2"));
+    assumeThat(spark.version())
+        .as("Spark 3 rejects writing nulls to a required column")
+        .startsWith("2");
 
-    File location = new File(temp.newFolder("parquet"), "test");
+    File location = temp.resolve("parquet").resolve("test").toFile();
     String sourcePath = String.format("%s/nullable_poc/sourceFolder/", location.toString());
     String targetPath = String.format("%s/nullable_poc/targetFolder/", location.toString());
 
@@ -330,15 +331,16 @@ public class TestDataFrameWrites extends AvroDataTest {
 
     // read all data
     List<Row> rows = spark.read().format("iceberg").load(targetPath).collectAsList();
-    Assert.assertEquals("Should contain 6 rows", 6, rows.size());
+    assumeThat(rows).as("Should contain 6 rows").hasSize(6);
   }
 
-  @Test
+  @TestTemplate
   public void testNullableWithSparkSqlOption() throws IOException {
-    Assume.assumeTrue(
-        "Spark 3 rejects writing nulls to a required column", spark.version().startsWith("2"));
+    assumeThat(spark.version())
+        .as("Spark 3 rejects writing nulls to a required column")
+        .startsWith("2");
 
-    File location = new File(temp.newFolder("parquet"), "test");
+    File location = temp.resolve("parquet").resolve("test").toFile();
     String sourcePath = String.format("%s/nullable_poc/sourceFolder/", location.toString());
     String targetPath = String.format("%s/nullable_poc/targetFolder/", location.toString());
 
@@ -389,10 +391,10 @@ public class TestDataFrameWrites extends AvroDataTest {
 
     // read all data
     List<Row> rows = newSparkSession.read().format("iceberg").load(targetPath).collectAsList();
-    Assert.assertEquals("Should contain 6 rows", 6, rows.size());
+    assumeThat(rows).as("Should contain 6 rows").hasSize(6);
   }
 
-  @Test
+  @TestTemplate
   public void testFaultToleranceOnWrite() throws IOException {
     File location = createTableFolder();
     Schema schema = new Schema(SUPPORTED_PRIMITIVES.fields());
@@ -408,8 +410,7 @@ public class TestDataFrameWrites extends AvroDataTest {
 
     Iterable<Record> records2 = RandomData.generate(schema, 100, 0L);
 
-    Assertions.assertThatThrownBy(
-            () -> writeDataWithFailOnPartition(records2, schema, location.toString()))
+    assertThatThrownBy(() -> writeDataWithFailOnPartition(records2, schema, location.toString()))
         .isInstanceOf(SparkException.class);
 
     table.refresh();
@@ -417,7 +418,7 @@ public class TestDataFrameWrites extends AvroDataTest {
     Snapshot snapshotAfterFailingWrite = table.currentSnapshot();
     List<Row> resultAfterFailingWrite = readTable(location.toString());
 
-    Assert.assertEquals(snapshotAfterFailingWrite, snapshotBeforeFailingWrite);
-    Assert.assertEquals(resultAfterFailingWrite, resultBeforeFailingWrite);
+    assertThat(snapshotBeforeFailingWrite).isEqualTo(snapshotAfterFailingWrite);
+    assertThat(resultBeforeFailingWrite).isEqualTo(resultAfterFailingWrite);
   }
 }
